# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/dynamic/v2/dynamic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/app/dynamic/v2/dynamic.proto\x12\x17\x62ilibili.app.dynamic.v2\x1a\x19google/protobuf/any.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"/\n\x07\x41\x64Param\x12\x10\n\x08\x61\x64_extra\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"\x9f\x02\n\x0e\x41\x64\x64itionCommon\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x39\n\x06\x62utton\x18\x07 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x11\n\thead_icon\x18\x08 \x01(\t\x12\x32\n\x05style\x18\t \x01(\x0e\x32#.bilibili.app.dynamic.v2.ImageStyle\x12\x0c\n\x04type\x18\n \x01(\t\x12\x11\n\tcard_type\x18\x0b \x01(\t\"\xbb\x01\n\x0e\x41\x64\x64itionEsport\x12\x33\n\x05style\x18\x01 \x01(\x0e\x32$.bilibili.app.dynamic.v2.EspaceStyle\x12K\n\x14\x61\x64\x64ition_esport_moba\x18\x02 \x01(\x0b\x32+.bilibili.app.dynamic.v2.AdditionEsportMobaH\x00\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x11\n\tcard_type\x18\x04 \x01(\tB\x06\n\x04item\"\xd5\x02\n\x12\x41\x64\x64itionEsportMoba\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x36\n\nmatch_team\x18\x03 \x03(\x0b\x32\".bilibili.app.dynamic.v2.MatchTeam\x12V\n\x1b\x61\x64\x64ition_esport_moba_status\x18\x04 \x01(\x0b\x32\x31.bilibili.app.dynamic.v2.AdditionEsportMobaStatus\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x39\n\x06\x62utton\x18\x06 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x11\n\tsub_title\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\n \x01(\t\x12\x11\n\tcard_type\x18\x0b \x01(\t\x12\x11\n\thead_icon\x18\x0c \x01(\t\"\xbe\x01\n\x18\x41\x64\x64itionEsportMobaStatus\x12_\n addition_esport_moba_status_desc\x18\x01 \x03(\x0b\x32\x35.bilibili.app.dynamic.v2.AdditionEsportMobaStatusDesc\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\x05\x12\r\n\x05\x63olor\x18\x04 \x01(\t\x12\x13\n\x0bnight_color\x18\x05 \x01(\t\"Q\n\x1c\x41\x64\x64itionEsportMobaStatusDesc\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\t\x12\x13\n\x0bnight_color\x18\x03 \x01(\t\"\x9e\x01\n\rAdditionGoods\x12\x11\n\trcmd_desc\x18\x01 \x01(\t\x12\x37\n\x0bgoods_items\x18\x02 \x03(\x0b\x32\".bilibili.app.dynamic.v2.GoodsItem\x12\x11\n\tcard_type\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x13\n\x0bsource_type\x18\x06 \x01(\x05\"\x99\x04\n\nAdditionUP\x12\r\n\x05title\x18\x01 \x01(\t\x12;\n\x0b\x64\x65sc_text_1\x18\x02 \x01(\x0b\x32&.bilibili.app.dynamic.v2.HighlightText\x12\x13\n\x0b\x64\x65sc_text_2\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x39\n\x06\x62utton\x18\x05 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x11\n\tcard_type\x18\x06 \x01(\t\x12\x15\n\rreserve_total\x18\x07 \x01(\x03\x12<\n\x08\x61\x63t_skin\x18\x08 \x01(\x0b\x32*.bilibili.app.dynamic.v2.AdditionalActSkin\x12\x0b\n\x03rid\x18\t \x01(\x03\x12\x14\n\x0clottery_type\x18\n \x01(\x05\x12:\n\ndesc_text3\x18\x0b \x01(\x0b\x32&.bilibili.app.dynamic.v2.HighlightText\x12\x0e\n\x06up_mid\x18\x0c \x01(\x03\x12<\n\tuser_info\x18\r \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionUserInfo\x12\x12\n\ndynamic_id\x18\x0e \x01(\t\x12\x12\n\nshow_text2\x18\x0f \x01(\x08\x12\x10\n\x08\x64yn_type\x18\x10 \x01(\x03\x12\x13\n\x0b\x62usiness_id\x18\x11 \x01(\t\"\xad\x01\n\x0b\x41\x64\x64itionUgc\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12\x10\n\x08\x64uration\x18\x07 \x01(\t\x12\x11\n\tline_feed\x18\x08 \x01(\x08\x12\x11\n\tcard_type\x18\t \x01(\t\".\n\x10\x41\x64\x64itionUserInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\"b\n\x0c\x41\x64\x64itionVote\x12\x11\n\timage_url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0e\n\x06text_1\x18\x03 \x01(\t\x12\x13\n\x0b\x62utton_text\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\"\x87\x05\n\rAdditionVote2\x12\x45\n\x12\x61\x64\x64ition_vote_type\x18\x01 \x01(\x0e\x32).bilibili.app.dynamic.v2.AdditionVoteType\x12\x0f\n\x07vote_id\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x01(\t\x12\x10\n\x08\x64\x65\x61\x64line\x18\x05 \x01(\x03\x12\x11\n\topen_text\x18\x06 \x01(\t\x12\x12\n\nclose_text\x18\x07 \x01(\t\x12\x12\n\nvoted_text\x18\x08 \x01(\t\x12\x39\n\x05state\x18\t \x01(\x0e\x32*.bilibili.app.dynamic.v2.AdditionVoteState\x12G\n\x12\x61\x64\x64ition_vote_word\x18\n \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionVoteWordH\x00\x12\x45\n\x11\x61\x64\x64ition_vote_pic\x18\x0b \x01(\x0b\x32(.bilibili.app.dynamic.v2.AdditionVotePicH\x00\x12M\n\x15\x61\x64\x64ition_vote_defaule\x18\x0c \x01(\x0b\x32,.bilibili.app.dynamic.v2.AdditionVoteDefauleH\x00\x12\x10\n\x08\x62iz_type\x18\r \x01(\x05\x12\r\n\x05total\x18\x0e \x01(\x03\x12\x11\n\tcard_type\x18\x0f \x01(\t\x12\x0c\n\x04tips\x18\x10 \x01(\t\x12\x0b\n\x03uri\x18\x11 \x01(\t\x12\x10\n\x08is_voted\x18\x12 \x01(\x08\x12\x12\n\nchoice_cnt\x18\x13 \x01(\x05\x12\x1c\n\x14\x64\x65\x66\x61ule_select_share\x18\x14 \x01(\x08\x42\x06\n\x04item\"$\n\x13\x41\x64\x64itionVoteDefaule\x12\r\n\x05\x63over\x18\x01 \x03(\t\"M\n\x0f\x41\x64\x64itionVotePic\x12:\n\x04item\x18\x01 \x03(\x0b\x32,.bilibili.app.dynamic.v2.AdditionVotePicItem\"\x8c\x01\n\x13\x41\x64\x64itionVotePicItem\x12\x0f\n\x07opt_idx\x18\x01 \x01(\x05\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0f\n\x07is_vote\x18\x03 \x01(\x08\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x0f\n\x07persent\x18\x05 \x01(\x01\x12\r\n\x05title\x18\x06 \x01(\t\x12\x15\n\ris_max_option\x18\x07 \x01(\x08\"O\n\x10\x41\x64\x64itionVoteWord\x12;\n\x04item\x18\x01 \x03(\x0b\x32-.bilibili.app.dynamic.v2.AdditionVoteWordItem\"~\n\x14\x41\x64\x64itionVoteWordItem\x12\x0f\n\x07opt_idx\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07is_vote\x18\x03 \x01(\x08\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x0f\n\x07persent\x18\x05 \x01(\x01\x12\x15\n\ris_max_option\x18\x06 \x01(\x08\"I\n\x11\x41\x64\x64itionalActSkin\x12\x0c\n\x04svga\x18\x01 \x01(\t\x12\x12\n\nlast_image\x18\x02 \x01(\t\x12\x12\n\nplay_times\x18\x03 \x01(\x03\"\xa7\x03\n\x10\x41\x64\x64itionalButton\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.bilibili.app.dynamic.v2.AddButtonType\x12\x42\n\njump_style\x18\x02 \x01(\x0b\x32..bilibili.app.dynamic.v2.AdditionalButtonStyle\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12?\n\x07uncheck\x18\x04 \x01(\x0b\x32..bilibili.app.dynamic.v2.AdditionalButtonStyle\x12=\n\x05\x63heck\x18\x05 \x01(\x0b\x32..bilibili.app.dynamic.v2.AdditionalButtonStyle\x12?\n\x06status\x18\x06 \x01(\x0e\x32/.bilibili.app.dynamic.v2.AdditionalButtonStatus\x12\x46\n\nclick_type\x18\x07 \x01(\x0e\x32\x32.bilibili.app.dynamic.v2.AdditionalButtonClickType\"\\\n\x1b\x41\x64\x64itionalButtonInteractive\x12\x0e\n\x06popups\x18\x01 \x01(\t\x12\x0f\n\x07\x63onfirm\x18\x02 \x01(\t\x12\x0e\n\x06\x63\x61ncel\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\"A\n\x15\x41\x64\x64itionalButtonShare\x12\x0c\n\x04show\x18\x01 \x01(\x05\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\"\xc1\x02\n\x15\x41\x64\x64itionalButtonStyle\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12I\n\x0binteractive\x18\x03 \x01(\x0b\x32\x34.bilibili.app.dynamic.v2.AdditionalButtonInteractive\x12;\n\x08\x62g_style\x18\x04 \x01(\x0e\x32).bilibili.app.dynamic.v2.AddButtonBgStyle\x12\r\n\x05toast\x18\x05 \x01(\t\x12\x36\n\x07\x64isable\x18\x06 \x01(\x0e\x32%.bilibili.app.dynamic.v2.DisableState\x12=\n\x05share\x18\x07 \x01(\x0b\x32..bilibili.app.dynamic.v2.AdditionalButtonShare\"\x8b\x02\n\rAdditionalPGC\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x39\n\x06\x62utton\x18\x07 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x11\n\thead_icon\x18\x08 \x01(\t\x12\x32\n\x05style\x18\t \x01(\x0e\x32#.bilibili.app.dynamic.v2.ImageStyle\x12\x0c\n\x04type\x18\n \x01(\t\"X\n\x13\x41lumniDynamicsReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\r\n\x05toast\x18\x02 \x01(\t\"\xa1\x01\n\x11\x41lumniDynamicsReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x12\n\nfirst_time\x18\x02 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\x12\x0c\n\x04page\x18\x05 \x01(\x05\"3\n\x10\x43\x61mpusBannerInfo\x12\r\n\x05image\x18\x01 \x01(\t\x12\x10\n\x08jump_url\x18\x02 \x01(\t\"\xfc\x01\n\x14\x43\x61mpusBillBoardReply\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08help_uri\x18\x02 \x01(\t\x12\x13\n\x0b\x63\x61mpus_name\x18\x03 \x01(\t\x12\x12\n\nbuild_time\x18\x04 \x01(\x03\x12\x14\n\x0cversion_code\x18\x05 \x01(\t\x12\x33\n\x04list\x18\x06 \x03(\x0b\x32%.bilibili.app.dynamic.v2.OfficialItem\x12\x11\n\tshare_uri\x18\x07 \x01(\t\x12\x13\n\x0b\x62ind_notice\x18\x08 \x01(\x05\x12\x14\n\x0cupdate_toast\x18\t \x01(\t\x12\x11\n\tcampus_id\x18\n \x01(\x03\"\x82\x01\n\x12\x43\x61mpusBillBoardReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x14\n\x0cversion_code\x18\x02 \x01(\t\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"R\n\x1a\x43\x61mpusBillboardInternalReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x11\n\tcampus_id\x18\x02 \x01(\x03\x12\x14\n\x0cversion_code\x18\x03 \x01(\t\"Y\n\x12\x43\x61mpusFeedbackInfo\x12\x10\n\x08\x62iz_type\x18\x01 \x01(\x05\x12\x0e\n\x06\x62iz_id\x18\x02 \x01(\x03\x12\x11\n\tcampus_id\x18\x03 \x01(\x03\x12\x0e\n\x06reason\x18\x04 \x01(\t\"&\n\x13\x43\x61mpusFeedbackReply\x12\x0f\n\x07message\x18\x01 \x01(\t\"]\n\x11\x43\x61mpusFeedbackReq\x12:\n\x05infos\x18\x01 \x03(\x0b\x32+.bilibili.app.dynamic.v2.CampusFeedbackInfo\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x05\"R\n\nCampusInfo\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x0e\n\x06online\x18\x04 \x01(\x03\"6\n\x0b\x43\x61mpusLabel\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\"N\n\x17\x43\x61mpusMateLikeListReply\x12\x33\n\x04list\x18\x01 \x03(\x0b\x32%.bilibili.app.dynamic.v2.ModuleAuthor\"+\n\x15\x43\x61mpusMateLikeListReq\x12\x12\n\ndynamic_id\x18\x01 \x01(\x03\"e\n\x10\x43\x61mpusNoticeInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x34\n\x06\x62utton\x18\x03 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\"\xb4\x01\n\x13\x43\x61mpusRcmdFeedReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\r\n\x05toast\x18\x02 \x01(\t\x12\x38\n\tguide_bar\x18\x03 \x01(\x0b\x32%.bilibili.app.dynamic.v2.GuideBarInfo\x12\x10\n\x08has_more\x18\x04 \x01(\x08\x12\x0e\n\x06update\x18\x05 \x01(\x08\"\xc6\x01\n\x11\x43\x61mpusRcmdFeedReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x12\n\nfirst_time\x18\x02 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\x12\x0c\n\x04page\x18\x05 \x01(\x05\x12\x0e\n\x06scroll\x18\x06 \x01(\x05\x12\x13\n\x0bview_dyn_id\x18\x07 \x01(\t\"W\n\x0e\x43\x61mpusRcmdInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.CampusRcmdItem\"\x9f\x01\n\x0e\x43\x61mpusRcmdItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x30\n\x05items\x18\x02 \x03(\x0b\x32!.bilibili.app.dynamic.v2.RcmdItem\x12\x11\n\tcampus_id\x18\x03 \x01(\x03\x12\x39\n\x0b\x65ntry_label\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\"\xc8\x01\n\x0f\x43\x61mpusRcmdReply\x12\x33\n\x03top\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.CampusRcmdTop\x12\x35\n\x04rcmd\x18\x02 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.CampusRcmdInfo\x12\x36\n\ncampus_top\x18\x03 \x01(\x0b\x32\".bilibili.app.dynamic.v2.CampusTop\x12\x11\n\tpage_type\x18\x04 \x01(\x05\"\x96\x01\n\rCampusRcmdReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x0b\n\x03lat\x18\x03 \x01(\x01\x12\x0b\n\x03lng\x18\x04 \x01(\x01\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\xc1\x03\n\rCampusRcmdTop\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\x05\x12\x36\n\x06\x62utton\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.RcmdTopButton\x12:\n\x0cswitch_label\x18\x07 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12:\n\x0cnotice_label\x18\x08 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\r\n\x05\x64\x65sc2\x18\t \x01(\t\x12\r\n\x05\x64\x65sc3\x18\n \x01(\t\x12:\n\x0cinvite_label\x18\x0b \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12;\n\rreserve_label\x18\x0c \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\x16\n\x0ereserve_number\x18\r \x01(\x03\"$\n\x11\x43\x61mpusRedDotReply\x12\x0f\n\x07red_dot\x18\x01 \x01(\x05\"$\n\x0f\x43\x61mpusRedDotReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\"M\n\x11\x43\x61mpusShowTabInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0f\n\x07red_dot\x18\x04 \x01(\x05\"\xdb\x03\n\tCampusTop\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x38\n\x04tabs\x18\x03 \x03(\x0b\x32*.bilibili.app.dynamic.v2.CampusShowTabInfo\x12:\n\x0cswitch_label\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\r\n\x05title\x18\x05 \x01(\t\x12\x39\n\x06\x62\x61nner\x18\x06 \x03(\x0b\x32).bilibili.app.dynamic.v2.CampusBannerInfo\x12:\n\x0cinvite_label\x18\x07 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\x39\n\x06notice\x18\x08 \x01(\x0b\x32).bilibili.app.dynamic.v2.CampusNoticeInfo\x12>\n\x0ctopic_square\x18\t \x01(\x0b\x32(.bilibili.app.dynamic.v2.TopicSquareInfo\x12\x14\n\x0c\x63\x61mpus_badge\x18\n \x01(\t\x12\x19\n\x11\x63\x61mpus_background\x18\x0b \x01(\t\"\x7f\n\x18\x43\x61mpusTopicRcmdFeedReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\r\n\x05toast\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x0e\n\x06offset\x18\x04 \x01(\t\"\x94\x01\n\x16\x43\x61mpusTopicRcmdFeedReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\"\x9d\x01\n\x10\x43\x61rdVideoDynList\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x12\n\nupdate_num\x18\x02 \x01(\x03\x12\x16\n\x0ehistory_offset\x18\x03 \x01(\t\x12\x17\n\x0fupdate_baseline\x18\x04 \x01(\t\x12\x10\n\x08has_more\x18\x05 \x01(\x08\"c\n\x13\x43\x61rdVideoFollowList\x12\x15\n\rview_all_link\x18\x01 \x01(\t\x12\x35\n\x04list\x18\x02 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.FollowListItem\"\x9e\x02\n\x0f\x43\x61rdVideoUpList\x12\r\n\x05title\x18\x01 \x01(\t\x12\x31\n\x04list\x18\x02 \x03(\x0b\x32#.bilibili.app.dynamic.v2.UpListItem\x12\x11\n\tfootprint\x18\x03 \x01(\t\x12\x15\n\rshow_live_num\x18\x04 \x01(\x05\x12<\n\nmore_label\x18\x05 \x01(\x0b\x32(.bilibili.app.dynamic.v2.UpListMoreLabel\x12\x14\n\x0ctitle_switch\x18\x06 \x01(\x05\x12\x17\n\x0fshow_more_label\x18\x07 \x01(\x08\x12\x18\n\x10show_in_personal\x18\x08 \x01(\x08\x12\x18\n\x10show_more_button\x18\t \x01(\x08\"\xbc\x01\n\x0b\x43hannelInfo\x12\x12\n\nchannel_id\x18\x01 \x01(\x03\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x10\n\x08is_atten\x18\x04 \x01(\x08\x12\x11\n\ttype_icon\x18\x05 \x01(\t\x12\x30\n\x05items\x18\x06 \x03(\x0b\x32!.bilibili.app.dynamic.v2.RcmdItem\x12\x0c\n\x04icon\x18\x07 \x01(\t\x12\x10\n\x08jump_uri\x18\x08 \x01(\t\"G\n\x0b\x43mtShowItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0f\n\x07\x63omment\x18\x04 \x01(\t\"3\n\rCommentDetail\x12\x12\n\ncan_modify\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\x03\"P\n\x0b\x44\x65\x63oCardFan\x12\x0e\n\x06is_fan\x18\x01 \x01(\x05\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12\x12\n\nnumber_str\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\"q\n\x0c\x44\x65\x63orateCard\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08\x63\x61rd_url\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x31\n\x03\x66\x61n\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DecoCardFan\"\xb7\x02\n\x0b\x44\x65scription\x12\x0c\n\x04text\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0e\x32!.bilibili.app.dynamic.v2.DescType\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x36\n\nemoji_type\x18\x04 \x01(\x0e\x32\".bilibili.app.dynamic.v2.EmojiType\x12\x12\n\ngoods_type\x18\x05 \x01(\t\x12\x10\n\x08icon_url\x18\x06 \x01(\t\x12\x11\n\ticon_name\x18\x07 \x01(\t\x12\x0b\n\x03rid\x18\x08 \x01(\t\x12\x37\n\x05goods\x18\t \x01(\x0b\x32(.bilibili.app.dynamic.v2.ModuleDescGoods\x12\x11\n\torig_text\x18\n \x01(\t\x12\x12\n\nemoji_size\x18\x0b \x01(\x05\":\n\tDimension\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05width\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x03\"_\n\x1c\x44ynAdditionCommonFollowReply\x12?\n\x06status\x18\x01 \x01(\x0e\x32/.bilibili.app.dynamic.v2.AdditionalButtonStatus\"\x80\x01\n\x1a\x44ynAdditionCommonFollowReq\x12?\n\x06status\x18\x01 \x01(\x0e\x32/.bilibili.app.dynamic.v2.AdditionalButtonStatus\x12\x0e\n\x06\x64yn_id\x18\x02 \x01(\t\x12\x11\n\tcard_type\x18\x03 \x01(\t\"\xf2\x01\n\x13\x44ynAllPersonalReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x13\n\x0bread_offset\x18\x04 \x01(\t\x12\x33\n\x08relation\x18\x05 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12;\n\x0b\x61\x64\x64ition_up\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.TopAdditionUP\"\x8f\x02\n\x11\x44ynAllPersonalReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x12\n\nis_preload\x18\x04 \x01(\x05\x12<\n\rplayurl_param\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x12\n\nlocal_time\x18\x06 \x01(\x05\x12\x11\n\tfootprint\x18\x07 \x01(\t\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x43\n\x0bplayer_args\x18\t \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\xae\x02\n\x0b\x44ynAllReply\x12:\n\x0c\x64ynamic_list\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicList\x12\x39\n\x07up_list\x18\x02 \x01(\x0b\x32(.bilibili.app.dynamic.v2.CardVideoUpList\x12\x36\n\ntopic_list\x18\x03 \x01(\x0b\x32\".bilibili.app.dynamic.v2.TopicList\x12\x33\n\x08unfollow\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Unfollow\x12;\n\x0bregion_rcmd\x18\x05 \x01(\x0b\x32&.bilibili.app.dynamic.v2.DynRegionRcmd\"\xf0\x03\n\tDynAllReq\x12\x17\n\x0fupdate_baseline\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x36\n\x0crefresh_type\x18\x04 \x01(\x0e\x32 .bilibili.app.dynamic.v2.Refresh\x12<\n\rplayurl_param\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x17\n\x0f\x61ssist_baseline\x18\x06 \x01(\t\x12\x12\n\nlocal_time\x18\x07 \x01(\x05\x12=\n\x0ercmd_ups_param\x18\x08 \x01(\x0b\x32%.bilibili.app.dynamic.v2.RcmdUPsParam\x12\x32\n\x08\x61\x64_param\x18\t \x01(\x0b\x32 .bilibili.app.dynamic.v2.AdParam\x12\x12\n\ncold_start\x18\n \x01(\x05\x12\x0c\n\x04\x66rom\x18\x0b \x01(\t\x12\x43\n\x0bplayer_args\x18\x0c \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x16\n\x0etab_recall_uid\x18\r \x01(\x03\x12\x17\n\x0ftab_recall_type\x18\x0e \x01(\x05\"N\n\x12\x44ynAllUpdOffsetReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x13\n\x0bread_offset\x18\x02 \x01(\t\x12\x11\n\tfootprint\x18\x03 \x01(\t\"D\n\x0e\x44ynDetailReply\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"\xa0\x02\n\x0c\x44ynDetailReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x12\n\ndynamic_id\x18\x02 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x03 \x01(\x03\x12\x0b\n\x03rid\x18\x04 \x01(\x03\x12\x32\n\x08\x61\x64_param\x18\x05 \x01(\x0b\x32 .bilibili.app.dynamic.v2.AdParam\x12\x0c\n\x04\x66rom\x18\x06 \x01(\t\x12\x43\n\x0bplayer_args\x18\x07 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08share_id\x18\x08 \x01(\t\x12\x12\n\nshare_mode\x18\t \x01(\x05\x12\x12\n\nlocal_time\x18\n \x01(\x05\x12\x0f\n\x07pattern\x18\x0b \x01(\t\"E\n\x0f\x44ynDetailsReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"\xbb\x01\n\rDynDetailsReq\x12\x13\n\x0b\x64ynamic_ids\x18\x01 \x01(\t\x12<\n\rplayurl_param\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x12\n\nlocal_time\x18\x03 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"F\n\x10\x44ynFakeCardReply\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"!\n\x0e\x44ynFakeCardReq\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"K\n\rDynLightReply\x12:\n\x0c\x64ynamic_list\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicList\"\xbf\x01\n\x0b\x44ynLightReq\x12\x16\n\x0ehistory_offset\x18\x01 \x01(\t\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x11\n\tfrom_type\x18\x06 \x01(\x05\x12\x10\n\x08\x66\x61ke_uid\x18\x07 \x01(\x03\"\xdf\x01\n\x19\x44ynMixUpListViewMoreReply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.app.dynamic.v2.MixUpListItem\x12\x1b\n\x13search_default_text\x18\x02 \x01(\t\x12\x35\n\nsort_types\x18\x03 \x03(\x0b\x32!.bilibili.app.dynamic.v2.SortType\x12\x1c\n\x14show_more_sort_types\x18\x04 \x01(\x08\x12\x19\n\x11\x64\x65\x66\x61ult_sort_type\x18\x05 \x01(\x05\",\n\x17\x44ynMixUpListViewMoreReq\x12\x11\n\tsort_type\x18\x01 \x01(\x05\"\x87\x01\n\x0c\x44ynRcmdReply\x12;\n\x0bregion_rcmd\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.DynRegionRcmd\x12:\n\x0c\x64ynamic_list\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicList\"\x8b\x01\n\nDynRcmdReq\x12\x43\n\x0bplayer_args\x18\x01 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x02 \x01(\x05\x12\x10\n\x08\x66\x61ke_uid\x18\x03 \x01(\x03\x12\x12\n\nis_refresh\x18\x04 \x01(\x08\"M\n\x16\x44ynRcmdUpExchangeReply\x12\x33\n\x08unfollow\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Unfollow\"D\n\x14\x44ynRcmdUpExchangeReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x11\n\tdislikeTs\x18\x02 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\"}\n\rDynRegionRcmd\x12\x39\n\x05items\x18\x01 \x03(\x0b\x32*.bilibili.app.dynamic.v2.DynRegionRcmdItem\x12\x31\n\x04opts\x18\x02 \x01(\x0b\x32#.bilibili.app.dynamic.v2.RcmdOption\"c\n\x11\x44ynRegionRcmdItem\x12\x0b\n\x03rid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x32\n\x05items\x18\x03 \x03(\x0b\x32#.bilibili.app.dynamic.v2.ModuleRcmd\"\xc4\x01\n\x0e\x44ynSearchReply\x12<\n\x0c\x63hannel_info\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.SearchChannel\x12:\n\x0csearch_topic\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.SearchTopic\x12\x38\n\x0bsearch_info\x18\x03 \x01(\x0b\x32#.bilibili.app.dynamic.v2.SearchInfo\"\x86\x01\n\x0c\x44ynSearchReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x12\n\nlocal_time\x18\x03 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\xb5\x01\n\x15\x44ynServerDetailsReply\x12H\n\x05items\x18\x01 \x03(\x0b\x32\x39.bilibili.app.dynamic.v2.DynServerDetailsReply.ItemsEntry\x1aR\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem:\x02\x38\x01\"\xe0\x01\n\x13\x44ynServerDetailsReq\x12\x12\n\nlocal_time\x18\x02 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08mobi_app\x18\x04 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x05 \x01(\t\x12\r\n\x05\x62uvid\x18\x06 \x01(\t\x12\r\n\x05\x62uild\x18\x07 \x01(\x03\x12\x0b\n\x03mid\x18\x08 \x01(\x03\x12\x10\n\x08platform\x18\t \x01(\t\x12\x11\n\tis_master\x18\n \x01(\x08\"\xac\x01\n\x0b\x44ynSpaceReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x16\n\x0ehistory_offset\x18\x02 \x01(\t\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\x12\x0c\n\x04page\x18\x05 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x06 \x01(\t\"k\n\x0b\x44ynSpaceRsp\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x16\n\x0ehistory_offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\"\xbf\x01\n\x1a\x44ynSpaceSearchDetailsReply\x12M\n\x05items\x18\x01 \x03(\x0b\x32>.bilibili.app.dynamic.v2.DynSpaceSearchDetailsReply.ItemsEntry\x1aR\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem:\x02\x38\x01\"\x97\x02\n\x18\x44ynSpaceSearchDetailsReq\x12\x14\n\x0csearch_words\x18\x02 \x03(\t\x12\x12\n\nlocal_time\x18\x03 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08mobi_app\x18\x05 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x06 \x01(\t\x12\r\n\x05\x62uvid\x18\x07 \x01(\t\x12\r\n\x05\x62uild\x18\x08 \x01(\x03\x12\x0b\n\x03mid\x18\t \x01(\x03\x12\x10\n\x08platform\x18\n \x01(\t\x12\n\n\x02ip\x18\x0b \x01(\t\x12\x10\n\x08net_type\x18\x0c \x01(\x05\x12\x0f\n\x07tf_type\x18\r \x01(\x05\"\xa8\x02\n\x06\x44ynTab\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0e\n\x06\x62ubble\x18\x03 \x01(\t\x12\x11\n\tred_point\x18\x04 \x01(\x05\x12\x0f\n\x07\x63ity_id\x18\x05 \x01(\x03\x12\x10\n\x08is_popup\x18\x06 \x01(\x05\x12-\n\x05popup\x18\x07 \x01(\x0b\x32\x1e.bilibili.app.dynamic.v2.Popup\x12\x13\n\x0b\x64\x65\x66\x61ult_tab\x18\x08 \x01(\x08\x12\x11\n\tsub_title\x18\t \x01(\t\x12\x0e\n\x06\x61nchor\x18\n \x01(\t\x12\x15\n\rinternal_test\x18\x0b \x01(\t\x12\x0c\n\x04type\x18\x0c \x01(\x05\x12\x30\n\x07\x62\x61\x63k_up\x18\r \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.DynTab\"?\n\x0b\x44ynTabReply\x12\x30\n\x07\x64yn_tab\x18\x01 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v2.DynTab\"#\n\tDynTabReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\"{\n\x0b\x44ynThumbReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0e\n\x06\x64yn_id\x18\x02 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x03 \x01(\x03\x12\x0b\n\x03rid\x18\x04 \x01(\t\x12\x30\n\x04type\x18\x05 \x01(\x0e\x32\".bilibili.app.dynamic.v2.ThumbType\"\xf4\x01\n\x15\x44ynVideoPersonalReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x13\n\x0bread_offset\x18\x04 \x01(\t\x12\x33\n\x08relation\x18\x05 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12;\n\x0b\x61\x64\x64ition_up\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.TopAdditionUP\"\x91\x02\n\x13\x44ynVideoPersonalReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x12\n\nis_preload\x18\x04 \x01(\x05\x12<\n\rplayurl_param\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x12\n\nlocal_time\x18\x06 \x01(\x05\x12\x11\n\tfootprint\x18\x07 \x01(\t\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x43\n\x0bplayer_args\x18\t \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\xda\x01\n\rDynVideoReply\x12?\n\x0c\x64ynamic_list\x18\x01 \x01(\x0b\x32).bilibili.app.dynamic.v2.CardVideoDynList\x12?\n\rvideo_up_list\x18\x02 \x01(\x0b\x32(.bilibili.app.dynamic.v2.CardVideoUpList\x12G\n\x11video_follow_list\x18\x03 \x01(\x0b\x32,.bilibili.app.dynamic.v2.CardVideoFollowList\"\xba\x02\n\x0b\x44ynVideoReq\x12\x17\n\x0fupdate_baseline\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x36\n\x0crefresh_type\x18\x04 \x01(\x0e\x32 .bilibili.app.dynamic.v2.Refresh\x12<\n\rplayurl_param\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x17\n\x0f\x61ssist_baseline\x18\x06 \x01(\t\x12\x12\n\nlocal_time\x18\x07 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x43\n\x0bplayer_args\x18\t \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"P\n\x14\x44ynVideoUpdOffsetReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x13\n\x0bread_offset\x18\x02 \x01(\t\x12\x11\n\tfootprint\x18\x03 \x01(\t\"S\n\x0c\x44ynVoteReply\x12\x34\n\x04item\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.AdditionVote2\x12\r\n\x05toast\x18\x02 \x01(\t\"\x84\x01\n\nDynVoteReq\x12\x0f\n\x07vote_id\x18\x01 \x01(\x03\x12\r\n\x05votes\x18\x02 \x03(\x03\x12\x33\n\x06status\x18\x03 \x01(\x0e\x32#.bilibili.app.dynamic.v2.VoteStatus\x12\x12\n\ndynamic_id\x18\x04 \x01(\t\x12\r\n\x05share\x18\x05 \x01(\x08\"\x89\x02\n\x0b\x44ynamicItem\x12\x37\n\tcard_type\x18\x01 \x01(\x0e\x32$.bilibili.app.dynamic.v2.DynamicType\x12\x37\n\titem_type\x18\x02 \x01(\x0e\x32$.bilibili.app.dynamic.v2.DynamicType\x12\x30\n\x07modules\x18\x03 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v2.Module\x12/\n\x06\x65xtend\x18\x04 \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.Extend\x12\x10\n\x08has_fold\x18\x05 \x01(\x05\x12\x13\n\x0bserver_info\x18\x06 \x01(\t\"\x98\x01\n\x0b\x44ynamicList\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x12\n\nupdate_num\x18\x02 \x01(\x03\x12\x16\n\x0ehistory_offset\x18\x03 \x01(\t\x12\x17\n\x0fupdate_baseline\x18\x04 \x01(\t\x12\x10\n\x08has_more\x18\x05 \x01(\x08\"\xe2\x01\n\rExtInfoCommon\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\x12\x34\n\x04type\x18\x05 \x01(\x0e\x32&.bilibili.app.dynamic.v2.DynExtendType\x12\x12\n\nsub_module\x18\x06 \x01(\t\x12\x13\n\x0b\x61\x63tion_text\x18\x07 \x01(\t\x12\x12\n\naction_url\x18\x08 \x01(\t\x12\x0b\n\x03rid\x18\t \x01(\x03\x12\x15\n\ris_show_light\x18\n \x01(\x08\"7\n\x0b\x45xtInfoGame\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"6\n\nExtInfoHot\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"H\n\nExtInfoLBS\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\"@\n\nExtInfoOGV\x12\x32\n\x08info_ogv\x18\x01 \x03(\x0b\x32 .bilibili.app.dynamic.v2.InfoOGV\"8\n\x0c\x45xtInfoTopic\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"\x94\x04\n\x06\x45xtend\x12\x12\n\ndyn_id_str\x18\x01 \x01(\t\x12\x13\n\x0b\x62usiness_id\x18\x02 \x01(\t\x12\x17\n\x0forig_dyn_id_str\x18\x03 \x01(\t\x12\x11\n\torig_name\x18\x04 \x01(\t\x12\x14\n\x0corig_img_url\x18\x05 \x01(\t\x12\x37\n\torig_desc\x18\x06 \x03(\x0b\x32$.bilibili.app.dynamic.v2.Description\x12\x32\n\x04\x64\x65sc\x18\x07 \x03(\x0b\x32$.bilibili.app.dynamic.v2.Description\x12;\n\rorig_dyn_type\x18\x08 \x01(\x0e\x32$.bilibili.app.dynamic.v2.DynamicType\x12\x12\n\nshare_type\x18\t \x01(\t\x12\x13\n\x0bshare_scene\x18\n \x01(\t\x12\x15\n\ris_fast_share\x18\x0b \x01(\x08\x12\x0e\n\x06r_type\x18\x0c \x01(\x05\x12\x10\n\x08\x64yn_type\x18\r \x01(\x03\x12\x0b\n\x03uid\x18\x0e \x01(\x03\x12\x10\n\x08\x63\x61rd_url\x18\x0f \x01(\t\x12,\n\x0esource_content\x18\x10 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\torig_face\x18\x11 \x01(\t\x12\x33\n\x05reply\x18\x12 \x01(\x0b\x32$.bilibili.app.dynamic.v2.ExtendReply\"U\n\x0b\x45xtendReply\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x39\n\x06params\x18\x02 \x03(\x0b\x32).bilibili.app.dynamic.v2.ExtendReplyParam\".\n\x10\x45xtendReplyParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x9e\x01\n\x0e\x46ollowListItem\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12.\n\x06new_ep\x18\x05 \x01(\x0b\x32\x1e.bilibili.app.dynamic.v2.NewEP\x12\x11\n\tsub_title\x18\x06 \x01(\t\x12\x0b\n\x03pos\x18\x07 \x01(\x03\"\x82\x02\n\tGoodsItem\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x1b\n\x13schema_package_name\x18\x02 \x01(\t\x12\x13\n\x0bsource_type\x18\x03 \x01(\x05\x12\x10\n\x08jump_url\x18\x04 \x01(\t\x12\x11\n\tjump_desc\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\r\n\x05\x62rief\x18\x07 \x01(\t\x12\r\n\x05price\x18\x08 \x01(\t\x12\x0f\n\x07item_id\x18\t \x01(\x03\x12\x12\n\nschema_url\x18\n \x01(\t\x12\x17\n\x0fopen_white_list\x18\x0b \x03(\t\x12\x13\n\x0buser_web_v2\x18\x0c \x01(\x08\x12\x0f\n\x07\x61\x64_mark\x18\r \x01(\t\"t\n\x0cGuideBarInfo\x12\x0c\n\x04show\x18\x01 \x01(\x05\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x10\n\x08position\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x11\n\tjump_page\x18\x05 \x01(\x05\x12\x15\n\rjump_position\x18\x06 \x01(\x05\"~\n\rHighlightText\x12\x0c\n\x04text\x18\x01 \x01(\t\x12?\n\ntext_style\x18\x02 \x01(\x0e\x32+.bilibili.app.dynamic.v2.HighlightTextStyle\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\".\n\tIconBadge\x12\x13\n\x0bicon_bg_url\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"R\n\nIconButton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x11\n\ticon_head\x18\x02 \x01(\t\x12\x11\n\ticon_tail\x18\x03 \x01(\t\x12\x10\n\x08jump_uri\x18\x04 \x01(\t\"G\n\x07InfoOGV\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x12\n\nsub_module\x18\x04 \x01(\t\",\n\x0fInteractionFace\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\"\xb5\x02\n\x0fInteractionItem\x12\x39\n\ticon_type\x18\x01 \x01(\x0e\x32&.bilibili.app.dynamic.v2.LocalIconType\x12\x32\n\x04\x64\x65sc\x18\x02 \x03(\x0b\x32$.bilibili.app.dynamic.v2.Description\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x12\n\ndynamic_id\x18\x04 \x01(\t\x12\x13\n\x0b\x63omment_mid\x18\x06 \x01(\x03\x12\x37\n\x05\x66\x61\x63\x65s\x18\x07 \x03(\x0b\x32(.bilibili.app.dynamic.v2.InteractionFace\x12\x36\n\x04stat\x18\x08 \x01(\x0b\x32(.bilibili.app.dynamic.v2.InteractionStat\x12\x0c\n\x04icon\x18\t \x01(\t\"\x1f\n\x0fInteractionStat\x12\x0c\n\x04like\x18\x01 \x01(\x03\"O\n\rLikeAnimation\x12\r\n\x05\x62\x65gin\x18\x01 \x01(\t\x12\x0c\n\x04proc\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\x14\n\x0clike_icon_id\x18\x04 \x01(\x03\"V\n\x08LikeInfo\x12\x39\n\tanimation\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.LikeAnimation\x12\x0f\n\x07is_like\x18\x02 \x01(\x08\"k\n\rLikeListReply\x12\x33\n\x04list\x18\x01 \x03(\x0b\x32%.bilibili.app.dynamic.v2.ModuleAuthor\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x13\n\x0btotal_count\x18\x03 \x01(\x03\"b\n\x0bLikeListReq\x12\x12\n\ndynamic_id\x18\x01 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x02 \x01(\x03\x12\x0b\n\x03rid\x18\x03 \x01(\x03\x12\x12\n\nuid_offset\x18\x04 \x01(\x03\x12\x0c\n\x04page\x18\x05 \x01(\x05\"3\n\x08LikeUser\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"b\n\x08LiveInfo\x12\x11\n\tis_living\x18\x01 \x01(\x05\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x36\n\nlive_state\x18\x03 \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\"=\n\x0bLivePendant\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x12\n\npendant_id\x18\x03 \x01(\x03\"X\n\tMatchTeam\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\x12\x13\n\x0bnight_color\x18\x05 \x01(\t\"\x8b\x01\n\x0cMdlDynApplet\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x11\n\tsub_title\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\x0c\n\x04icon\x18\x07 \x01(\t\x12\r\n\x05label\x18\x08 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\t \x01(\t\"\xdd\x05\n\rMdlDynArchive\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0c\n\x04\x61vid\x18\x07 \x01(\x03\x12\x0b\n\x03\x63id\x18\x08 \x01(\x03\x12\x36\n\nmedia_type\x18\t \x01(\x0e\x32\".bilibili.app.dynamic.v2.MediaType\x12\x35\n\tdimension\x18\n \x01(\x0b\x32\".bilibili.app.dynamic.v2.Dimension\x12\x32\n\x05\x62\x61\x64ge\x18\x0b \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x0c \x01(\x08\x12\x31\n\x05stype\x18\r \x01(\x0e\x32\".bilibili.app.dynamic.v2.VideoType\x12\r\n\x05isPGC\x18\x0e \x01(\x08\x12\x11\n\tinlineURL\x18\x0f \x01(\t\x12\x11\n\tEpisodeId\x18\x10 \x01(\x03\x12\x0f\n\x07SubType\x18\x11 \x01(\x05\x12\x13\n\x0bPgcSeasonId\x18\x12 \x01(\x03\x12\x11\n\tplay_icon\x18\x13 \x01(\t\x12\x10\n\x08\x64uration\x18\x14 \x01(\x03\x12\x10\n\x08jump_url\x18\x15 \x01(\t\x12\x12\n\nis_preview\x18\x16 \x01(\x08\x12;\n\x0e\x62\x61\x64ge_category\x18\x17 \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x12\n\nis_feature\x18\x18 \x01(\x08\x12:\n\x0creserve_type\x18\x19 \x01(\x0e\x32$.bilibili.app.dynamic.v2.ReserveType\x12\x0c\n\x04\x62vid\x18\x1a \x01(\t\x12\x0c\n\x04view\x18\x1b \x01(\x05\"x\n\rMdlDynArticle\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x0e\n\x06\x63overs\x18\x05 \x03(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12\x12\n\ntemplateID\x18\x07 \x01(\x05\"\xaf\x02\n\x0cMdlDynCommon\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12\x0f\n\x07\x62izType\x18\x07 \x01(\x05\x12\x10\n\x08sketchID\x18\x08 \x01(\x03\x12\x38\n\x05style\x18\t \x01(\x0e\x32).bilibili.app.dynamic.v2.MdlDynCommonType\x12\x32\n\x05\x62\x61\x64ge\x18\n \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x39\n\x06\x62utton\x18\x0b \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\"\xa3\x01\n\x0fMdlDynCourBatch\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0e\n\x06text_2\x18\x05 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x11\n\tplay_icon\x18\x07 \x01(\t\"\xa2\x01\n\x10MdlDynCourSeason\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x11\n\tplay_icon\x18\x07 \x01(\t\"]\n\nMdlDynDraw\x12\x36\n\x05items\x18\x01 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.MdlDynDrawItem\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x03\"\x80\x01\n\x0eMdlDynDrawItem\x12\x0b\n\x03src\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x03\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x0c\n\x04size\x18\x04 \x01(\x02\x12\x34\n\x04tags\x18\x05 \x03(\x0b\x32&.bilibili.app.dynamic.v2.MdlDynDrawTag\"\x83\x01\n\rMdlDynDrawTag\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.bilibili.app.dynamic.v2.MdlDynDrawTagType\x12\x38\n\x04item\x18\x02 \x01(\x0b\x32*.bilibili.app.dynamic.v2.MdlDynDrawTagItem\"\xb5\x01\n\x11MdlDynDrawTagItem\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\t\n\x01x\x18\x03 \x01(\x03\x12\t\n\x01y\x18\x04 \x01(\x03\x12\x13\n\x0borientation\x18\x05 \x01(\x05\x12\x0e\n\x06source\x18\x06 \x01(\x05\x12\x0f\n\x07item_id\x18\x07 \x01(\x03\x12\x0b\n\x03mid\x18\x08 \x01(\x03\x12\x0b\n\x03tid\x18\t \x01(\x03\x12\x0b\n\x03poi\x18\n \x01(\t\x12\x12\n\nschema_url\x18\x0b \x01(\t\"R\n\rMdlDynForward\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\r\n\x05rtype\x18\x02 \x01(\x05\"\x96\x02\n\nMdlDynLive\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x13\n\x0b\x63over_label\x18\x05 \x01(\t\x12\x14\n\x0c\x63over_label2\x18\x06 \x01(\t\x12\x36\n\nlive_state\x18\x07 \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\x12\x32\n\x05\x62\x61\x64ge\x18\x08 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12:\n\x0creserve_type\x18\t \x01(\x0e\x32$.bilibili.app.dynamic.v2.ReserveType\"\x94\x01\n\x0eMdlDynLiveRcmd\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12:\n\x0creserve_type\x18\x02 \x01(\x0e\x32$.bilibili.app.dynamic.v2.ReserveType\x12\x35\n\x07pendant\x18\x03 \x01(\x0b\x32$.bilibili.app.dynamic.v2.LivePendant\"\xa3\x01\n\x0fMdlDynMedialist\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x11\n\tsub_title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x12\n\ncover_type\x18\x06 \x01(\x05\x12\x32\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\"r\n\x0bMdlDynMusic\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05up_id\x18\x03 \x01(\x03\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x0e\n\x06label1\x18\x06 \x01(\t\x12\r\n\x05upper\x18\x07 \x01(\t\"\x80\x05\n\tMdlDynPGC\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0b\n\x03\x63id\x18\x07 \x01(\x03\x12\x11\n\tseason_id\x18\x08 \x01(\x03\x12\x0c\n\x04\x65pid\x18\t \x01(\x03\x12\x0b\n\x03\x61id\x18\n \x01(\x03\x12\x36\n\nmedia_type\x18\x0b \x01(\x0e\x32\".bilibili.app.dynamic.v2.MediaType\x12\x37\n\x08sub_type\x18\x0c \x01(\x0e\x32%.bilibili.app.dynamic.v2.VideoSubType\x12\x12\n\nis_preview\x18\r \x01(\x08\x12\x35\n\tdimension\x18\x0e \x01(\x0b\x32\".bilibili.app.dynamic.v2.Dimension\x12\x32\n\x05\x62\x61\x64ge\x18\x0f \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x10 \x01(\x08\x12\x32\n\x06season\x18\x11 \x01(\x0b\x32\".bilibili.app.dynamic.v2.PGCSeason\x12\x11\n\tplay_icon\x18\x12 \x01(\t\x12\x10\n\x08\x64uration\x18\x13 \x01(\x03\x12\x10\n\x08jump_url\x18\x14 \x01(\t\x12;\n\x0e\x62\x61\x64ge_category\x18\x15 \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x12\n\nis_feature\x18\x16 \x01(\x08\"\xae\x01\n\x12MdlDynSubscription\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05\x61\x64_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x10\n\x08\x61\x64_title\x18\x06 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x0c\n\x04tips\x18\x08 \x01(\t\"\xee\x01\n\x15MdlDynSubscriptionNew\x12\x42\n\x05style\x18\x01 \x01(\x0e\x32\x33.bilibili.app.dynamic.v2.MdlDynSubscriptionNewStyle\x12G\n\x10\x64yn_subscription\x18\x02 \x01(\x0b\x32+.bilibili.app.dynamic.v2.MdlDynSubscriptionH\x00\x12@\n\rdyn_live_rcmd\x18\x03 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.MdlDynLiveRcmdH\x00\x42\x06\n\x04item\"\xc7\x02\n\x0fMdlDynUGCSeason\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\x03\x12\x11\n\tinlineURL\x18\x08 \x01(\t\x12\x10\n\x08\x63\x61n_play\x18\t \x01(\x08\x12\x11\n\tplay_icon\x18\n \x01(\t\x12\x0c\n\x04\x61vid\x18\x0b \x01(\x03\x12\x0b\n\x03\x63id\x18\x0c \x01(\x03\x12\x35\n\tdimension\x18\r \x01(\x0b\x32\".bilibili.app.dynamic.v2.Dimension\x12\x10\n\x08\x64uration\x18\x0e \x01(\x03\x12\x10\n\x08jump_url\x18\x0f \x01(\t\"\xeb\x02\n\rMixUpListItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x19\n\x11special_attention\x18\x02 \x01(\x05\x12\x14\n\x0creddot_state\x18\x03 \x01(\x05\x12=\n\tlive_info\x18\x04 \x01(\x0b\x32*.bilibili.app.dynamic.v2.MixUpListLiveItem\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x06 \x01(\t\x12\x39\n\x08official\x18\x07 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.OfficialVerify\x12-\n\x03vip\x18\x08 \x01(\x0b\x32 .bilibili.app.dynamic.v2.VipInfo\x12\x33\n\x08relation\x18\t \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12\x15\n\rpermire_state\x18\n \x01(\x05\x12\x0b\n\x03uri\x18\x0b \x01(\t\"A\n\x11MixUpListLiveItem\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\x93\x0e\n\x06Module\x12;\n\x0bmodule_type\x18\x01 \x01(\x0e\x32&.bilibili.app.dynamic.v2.DynModuleType\x12>\n\rmodule_author\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleAuthorH\x00\x12@\n\x0emodule_dispute\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.ModuleDisputeH\x00\x12:\n\x0bmodule_desc\x18\x04 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleDescH\x00\x12@\n\x0emodule_dynamic\x18\x05 \x01(\x0b\x32&.bilibili.app.dynamic.v2.ModuleDynamicH\x00\x12\x42\n\x0fmodule_likeUser\x18\x06 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.ModuleLikeUserH\x00\x12>\n\rmodule_extend\x18\x07 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleExtendH\x00\x12\x46\n\x11module_additional\x18\x08 \x01(\x0b\x32).bilibili.app.dynamic.v2.ModuleAdditionalH\x00\x12:\n\x0bmodule_stat\x18\t \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleStatH\x00\x12:\n\x0bmodule_fold\x18\n \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleFoldH\x00\x12@\n\x0emodule_comment\x18\x0b \x01(\x0b\x32&.bilibili.app.dynamic.v2.ModuleCommentH\x00\x12H\n\x12module_interaction\x18\x0c \x01(\x0b\x32*.bilibili.app.dynamic.v2.ModuleInteractionH\x00\x12M\n\x15module_author_forward\x18\r \x01(\x0b\x32,.bilibili.app.dynamic.v2.ModuleAuthorForwardH\x00\x12\x36\n\tmodule_ad\x18\x0e \x01(\x0b\x32!.bilibili.app.dynamic.v2.ModuleAdH\x00\x12>\n\rmodule_banner\x18\x0f \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleBannerH\x00\x12\x43\n\x10module_item_null\x18\x10 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.ModuleItemNullH\x00\x12\x45\n\x11module_share_info\x18\x11 \x01(\x0b\x32(.bilibili.app.dynamic.v2.ModuleShareInfoH\x00\x12\x44\n\x10module_recommend\x18\x12 \x01(\x0b\x32(.bilibili.app.dynamic.v2.ModuleRecommendH\x00\x12\x38\n\nmodule_top\x18\x13 \x01(\x0b\x32\".bilibili.app.dynamic.v2.ModuleTopH\x00\x12>\n\rmodule_buttom\x18\x14 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleButtomH\x00\x12\x42\n\x13module_stat_forward\x18\x15 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleStatH\x00\x12<\n\x0cmodule_story\x18\x16 \x01(\x0b\x32$.bilibili.app.dynamic.v2.ModuleStoryH\x00\x12<\n\x0cmodule_topic\x18\x17 \x01(\x0b\x32$.bilibili.app.dynamic.v2.ModuleTopicH\x00\x12R\n\x18module_topic_details_ext\x18\x18 \x01(\x0b\x32..bilibili.app.dynamic.v2.ModuleTopicDetailsExtH\x00\x12?\n\x0emodule_top_tag\x18\x19 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleTopTagH\x00\x12G\n\x12module_topic_brief\x18\x1a \x01(\x0b\x32).bilibili.app.dynamic.v2.ModuleTopicBriefH\x00\x12<\n\x0cmodule_title\x18\x1b \x01(\x0b\x32$.bilibili.app.dynamic.v2.ModuleTitleH\x00\x42\r\n\x0bmodule_item\"\xdd\x01\n\x08ModuleAd\x12,\n\x0esource_content\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12<\n\rmodule_author\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleAuthor\x12\x17\n\x0f\x61\x64_content_type\x18\x03 \x01(\x05\x12\x18\n\x10\x63over_left_text1\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_text2\x18\x05 \x01(\t\x12\x18\n\x10\x63over_left_text3\x18\x06 \x01(\t\"\xb9\x04\n\x10ModuleAdditional\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.bilibili.app.dynamic.v2.AdditionalType\x12\x35\n\x03pgc\x18\x02 \x01(\x0b\x32&.bilibili.app.dynamic.v2.AdditionalPGCH\x00\x12\x37\n\x05goods\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.AdditionGoodsH\x00\x12\x35\n\x04vote\x18\x04 \x01(\x0b\x32%.bilibili.app.dynamic.v2.AdditionVoteH\x00\x12\x39\n\x06\x63ommon\x18\x05 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.AdditionCommonH\x00\x12\x39\n\x06\x65sport\x18\x06 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.AdditionEsportH\x00\x12\x37\n\x05vote2\x18\x08 \x01(\x0b\x32&.bilibili.app.dynamic.v2.AdditionVote2H\x00\x12\x33\n\x03ugc\x18\t \x01(\x0b\x32$.bilibili.app.dynamic.v2.AdditionUgcH\x00\x12\x31\n\x02up\x18\n \x01(\x0b\x32#.bilibili.app.dynamic.v2.AdditionUPH\x00\x12\x0b\n\x03rid\x18\x07 \x01(\x03\x12\x1b\n\x13need_write_calender\x18\x0b \x01(\x08\x42\x06\n\x04item\"\xc5\x04\n\x0cModuleAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x18\n\x10ptime_label_text\x18\x02 \x01(\t\x12\x31\n\x06\x61uthor\x18\x03 \x01(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12<\n\rdecorate_card\x18\x04 \x01(\x0b\x32%.bilibili.app.dynamic.v2.DecorateCard\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x38\n\x07tp_list\x18\x06 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointItem\x12\x42\n\nbadge_type\x18\x07 \x01(\x0e\x32..bilibili.app.dynamic.v2.ModuleAuthorBadgeType\x12\x46\n\x0c\x62\x61\x64ge_button\x18\x08 \x01(\x0b\x32\x30.bilibili.app.dynamic.v2.ModuleAuthorBadgeButton\x12\x0e\n\x06\x61ttend\x18\t \x01(\x05\x12\x33\n\x08relation\x18\n \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12/\n\x06weight\x18\x0b \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.Weight\x12\x13\n\x0bshow_follow\x18\x0c \x01(\x08\x12\x0e\n\x06is_top\x18\r \x01(\x08\x12\x1b\n\x13ptime_location_text\x18\x0e \x01(\t\x12\x12\n\nshow_level\x18\x0f \x01(\x08\"Q\n\x17ModuleAuthorBadgeButton\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\x05\x12\n\n\x02id\x18\x04 \x01(\x03\"\xa1\x02\n\x13ModuleAuthorForward\x12@\n\x05title\x18\x01 \x03(\x0b\x32\x31.bilibili.app.dynamic.v2.ModuleAuthorForwardTitle\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x18\n\x10ptime_label_text\x18\x04 \x01(\t\x12\x13\n\x0bshow_follow\x18\x05 \x01(\x08\x12\x10\n\x08\x66\x61\x63\x65_url\x18\x06 \x01(\t\x12\x33\n\x08relation\x18\x07 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12\x38\n\x07tp_list\x18\x08 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointItem\"5\n\x18ModuleAuthorForwardTitle\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\xc5\x01\n\x0cModuleBanner\x12\r\n\x05title\x18\x01 \x01(\t\x12\x37\n\x04type\x18\x02 \x01(\x0e\x32).bilibili.app.dynamic.v2.ModuleBannerType\x12\x39\n\x04user\x18\x03 \x01(\x0b\x32).bilibili.app.dynamic.v2.ModuleBannerUserH\x00\x12\x14\n\x0c\x64islike_text\x18\x04 \x01(\t\x12\x14\n\x0c\x64islike_icon\x18\x05 \x01(\tB\x06\n\x04item\"O\n\x10ModuleBannerUser\x12;\n\x04list\x18\x01 \x03(\x0b\x32-.bilibili.app.dynamic.v2.ModuleBannerUserItem\"\xb8\x02\n\x14ModuleBannerUserItem\x12\x0c\n\x04\x66\x61\x63\x65\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x36\n\nlive_state\x18\x04 \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\x12\x39\n\x08official\x18\x05 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.OfficialVerify\x12-\n\x03vip\x18\x06 \x01(\x0b\x32 .bilibili.app.dynamic.v2.VipInfo\x12\r\n\x05label\x18\x07 \x01(\t\x12\x39\n\x06\x62utton\x18\x08 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x0b\n\x03uri\x18\t \x01(\t\"H\n\x0cModuleButtom\x12\x38\n\x0bmodule_stat\x18\x01 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleStat\"J\n\rModuleComment\x12\x39\n\x0b\x63mtShowItem\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.CmtShowItem\"`\n\nModuleDesc\x12\x32\n\x04\x64\x65sc\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.Description\x12\x10\n\x08jump_uri\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\"\xb9\x01\n\x0fModuleDescGoods\x12\x13\n\x0bsource_type\x18\x01 \x01(\x05\x12\x10\n\x08jump_url\x18\x02 \x01(\t\x12\x12\n\nschema_url\x18\x03 \x01(\t\x12\x0f\n\x07item_id\x18\x04 \x01(\x03\x12\x17\n\x0fopen_white_list\x18\x05 \x03(\t\x12\x13\n\x0buser_web_v2\x18\x06 \x01(\x08\x12\x0f\n\x07\x61\x64_mark\x18\x07 \x01(\t\x12\x1b\n\x13schema_package_name\x18\x08 \x01(\t\"9\n\rModuleDispute\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\xe6\x08\n\rModuleDynamic\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.bilibili.app.dynamic.v2.ModuleDynamicType\x12=\n\x0b\x64yn_archive\x18\x02 \x01(\x0b\x32&.bilibili.app.dynamic.v2.MdlDynArchiveH\x00\x12\x35\n\x07\x64yn_pgc\x18\x03 \x01(\x0b\x32\".bilibili.app.dynamic.v2.MdlDynPGCH\x00\x12\x44\n\x0f\x64yn_cour_season\x18\x04 \x01(\x0b\x32).bilibili.app.dynamic.v2.MdlDynCourSeasonH\x00\x12\x42\n\x0e\x64yn_cour_batch\x18\x05 \x01(\x0b\x32(.bilibili.app.dynamic.v2.MdlDynCourBatchH\x00\x12=\n\x0b\x64yn_forward\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.MdlDynForwardH\x00\x12\x37\n\x08\x64yn_draw\x18\x07 \x01(\x0b\x32#.bilibili.app.dynamic.v2.MdlDynDrawH\x00\x12=\n\x0b\x64yn_article\x18\x08 \x01(\x0b\x32&.bilibili.app.dynamic.v2.MdlDynArticleH\x00\x12\x39\n\tdyn_music\x18\t \x01(\x0b\x32$.bilibili.app.dynamic.v2.MdlDynMusicH\x00\x12;\n\ndyn_common\x18\n \x01(\x0b\x32%.bilibili.app.dynamic.v2.MdlDynCommonH\x00\x12>\n\x0f\x64yn_common_live\x18\x0b \x01(\x0b\x32#.bilibili.app.dynamic.v2.MdlDynLiveH\x00\x12\x41\n\rdyn_medialist\x18\x0c \x01(\x0b\x32(.bilibili.app.dynamic.v2.MdlDynMedialistH\x00\x12;\n\ndyn_applet\x18\r \x01(\x0b\x32%.bilibili.app.dynamic.v2.MdlDynAppletH\x00\x12G\n\x10\x64yn_subscription\x18\x0e \x01(\x0b\x32+.bilibili.app.dynamic.v2.MdlDynSubscriptionH\x00\x12@\n\rdyn_live_rcmd\x18\x0f \x01(\x0b\x32\'.bilibili.app.dynamic.v2.MdlDynLiveRcmdH\x00\x12\x42\n\x0e\x64yn_ugc_season\x18\x10 \x01(\x0b\x32(.bilibili.app.dynamic.v2.MdlDynUGCSeasonH\x00\x12N\n\x14\x64yn_subscription_new\x18\x11 \x01(\x0b\x32..bilibili.app.dynamic.v2.MdlDynSubscriptionNewH\x00\x42\r\n\x0bmodule_item\"V\n\x0cModuleExtend\x12\x39\n\x06\x65xtend\x18\x01 \x03(\x0b\x32).bilibili.app.dynamic.v2.ModuleExtendItem\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xcc\x03\n\x10ModuleExtendItem\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.bilibili.app.dynamic.v2.DynExtendType\x12?\n\x0e\x65xt_info_topic\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ExtInfoTopicH\x00\x12;\n\x0c\x65xt_info_lbs\x18\x03 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ExtInfoLBSH\x00\x12;\n\x0c\x65xt_info_hot\x18\x04 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ExtInfoHotH\x00\x12=\n\rext_info_game\x18\x05 \x01(\x0b\x32$.bilibili.app.dynamic.v2.ExtInfoGameH\x00\x12\x41\n\x0f\x65xt_info_common\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.ExtInfoCommonH\x00\x12;\n\x0c\x65xt_info_ogv\x18\x07 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ExtInfoOGVH\x00\x42\x08\n\x06\x65xtend\"\x99\x01\n\nModuleFold\x12\x34\n\tfold_type\x18\x01 \x01(\x0e\x32!.bilibili.app.dynamic.v2.FoldType\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08\x66old_ids\x18\x03 \x01(\t\x12\x35\n\nfold_users\x18\x04 \x03(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\"W\n\x11ModuleInteraction\x12\x42\n\x10interaction_item\x18\x01 \x03(\x0b\x32(.bilibili.app.dynamic.v2.InteractionItem\",\n\x0eModuleItemNull\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"]\n\x0eModuleLikeUser\x12\x35\n\nlike_users\x18\x01 \x03(\x0b\x32!.bilibili.app.dynamic.v2.LikeUser\x12\x14\n\x0c\x64isplay_text\x18\x02 \x01(\t\"\x88\x01\n\nModuleRcmd\x12\x33\n\x06\x61uthor\x18\x01 \x01(\x0b\x32#.bilibili.app.dynamic.v2.RcmdAuthor\x12\x30\n\x05items\x18\x02 \x03(\x0b\x32!.bilibili.app.dynamic.v2.RcmdItem\x12\x13\n\x0bserver_info\x18\x03 \x01(\t\"\x86\x01\n\x0fModuleRecommend\x12\x14\n\x0cmodule_title\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x10\n\x08jump_url\x18\x05 \x01(\t\x12 \n\x02\x61\x64\x18\x06 \x03(\x0b\x32\x14.google.protobuf.Any\"\x8f\x01\n\x0fModuleShareInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12=\n\x0eshare_channels\x18\x02 \x03(\x0b\x32%.bilibili.app.dynamic.v2.ShareChannel\x12\x14\n\x0cshare_origin\x18\x03 \x01(\t\x12\x0b\n\x03oid\x18\x04 \x01(\t\x12\x0b\n\x03sid\x18\x05 \x01(\t\"\xdc\x01\n\nModuleStat\x12\x0e\n\x06repost\x18\x01 \x01(\x03\x12\x0c\n\x04like\x18\x02 \x01(\x03\x12\r\n\x05reply\x18\x03 \x01(\x03\x12\x34\n\tlike_info\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v2.LikeInfo\x12\x12\n\nno_comment\x18\x05 \x01(\x08\x12\x12\n\nno_forward\x18\x06 \x01(\x08\x12\x11\n\treply_url\x18\x07 \x01(\t\x12\x17\n\x0fno_comment_text\x18\x08 \x01(\t\x12\x17\n\x0fno_forward_text\x18\t \x01(\t\"\xb4\x01\n\x0bModuleStory\x12\r\n\x05title\x18\x01 \x01(\t\x12\x31\n\x05items\x18\x02 \x03(\x0b\x32\".bilibili.app.dynamic.v2.StoryItem\x12\x1d\n\x15show_publish_entrance\x18\x03 \x01(\x08\x12\x12\n\nfold_state\x18\x04 \x01(\x03\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\x14\n\x0cpublish_text\x18\x07 \x01(\t\"T\n\x0bModuleTitle\x12\r\n\x05title\x18\x01 \x01(\t\x12\x36\n\tright_btn\x18\x02 \x01(\x0b\x32#.bilibili.app.dynamic.v2.IconButton\"E\n\tModuleTop\x12\x38\n\x07tp_list\x18\x01 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointItem\" \n\x0cModuleTopTag\x12\x10\n\x08tag_name\x18\x01 \x01(\t\"4\n\x0bModuleTopic\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\"E\n\x10ModuleTopicBrief\x12\x31\n\x05topic\x18\x01 \x01(\x0b\x32\".bilibili.app.dynamic.v2.TopicItem\".\n\x15ModuleTopicDetailsExt\x12\x15\n\rcomment_guide\x18\x01 \x01(\t\"l\n\tNameplate\x12\x0b\n\x03nid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x13\n\x0bimage_small\x18\x04 \x01(\t\x12\r\n\x05level\x18\x05 \x01(\t\x12\x11\n\tcondition\x18\x06 \x01(\t\"6\n\x05NewEP\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nindex_show\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\"\t\n\x07NoReply\"\x07\n\x05NoReq\"\xbf\x01\n\x13OfficialAccountInfo\x12\x31\n\x06\x61uthor\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x33\n\x08relation\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12\x12\n\ndesc_text1\x18\x05 \x01(\t\x12\x12\n\ndesc_text2\x18\x06 \x01(\t\"v\n\x15OfficialAccountsReply\x12;\n\x05items\x18\x01 \x03(\x0b\x32,.bilibili.app.dynamic.v2.OfficialAccountInfo\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x0e\n\x06offset\x18\x03 \x01(\x03\"M\n\x13OfficialAccountsReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x03\"\xb4\x01\n\x15OfficialDynamicsReply\x12\x34\n\x05items\x18\x01 \x03(\x0b\x32%.bilibili.app.dynamic.v2.OfficialItem\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"M\n\x13OfficialDynamicsReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x03\"\xb5\x01\n\x0cOfficialItem\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x44\n\x0crcmd_archive\x18\x02 \x01(\x0b\x32,.bilibili.app.dynamic.v2.OfficialRcmdArchiveH\x00\x12\x44\n\x0crcmd_dynamic\x18\x03 \x01(\x0b\x32,.bilibili.app.dynamic.v2.OfficialRcmdDynamicH\x00\x42\x0b\n\trcmd_item\"\x9d\x02\n\x13OfficialRcmdArchive\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x18\n\x10\x63over_right_text\x18\x03 \x01(\t\x12\x12\n\ndesc_icon1\x18\x04 \x01(\x05\x12\x12\n\ndesc_text1\x18\x05 \x01(\t\x12\x12\n\ndesc_icon2\x18\x06 \x01(\x05\x12\x12\n\ndesc_text2\x18\x07 \x01(\t\x12\x0e\n\x06reason\x18\x08 \x01(\t\x12\x18\n\x10show_three_point\x18\t \x01(\x08\x12\x0b\n\x03uri\x18\n \x01(\t\x12\x0b\n\x03\x61id\x18\x0b \x01(\x03\x12\x0b\n\x03mid\x18\x0c \x01(\x03\x12\x0c\n\x04name\x18\r \x01(\t\x12\x12\n\ndynamic_id\x18\x0e \x01(\x03\x12\x0b\n\x03\x63id\x18\x0f \x01(\x03\"\xff\x01\n\x13OfficialRcmdDynamic\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x1c\n\x14\x63over_right_top_text\x18\x03 \x01(\t\x12\x12\n\ndesc_icon1\x18\x04 \x01(\x05\x12\x12\n\ndesc_text1\x18\x05 \x01(\t\x12\x12\n\ndesc_icon2\x18\x06 \x01(\x05\x12\x12\n\ndesc_text2\x18\x07 \x01(\t\x12\x0e\n\x06reason\x18\x08 \x01(\t\x12\x0b\n\x03uri\x18\t \x01(\t\x12\x12\n\ndynamic_id\x18\n \x01(\x03\x12\x0b\n\x03mid\x18\x0b \x01(\x03\x12\x11\n\tuser_name\x18\x0c \x01(\t\x12\x0b\n\x03rid\x18\r \x01(\x03\">\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x10\n\x08is_atten\x18\x03 \x01(\x05\";\n\tPGCSeason\x12\x11\n\tis_finish\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\"[\n\x0cPlayurlParam\x12\n\n\x02qn\x18\x01 \x01(\x05\x12\r\n\x05\x66nver\x18\x02 \x01(\x05\x12\r\n\x05\x66nval\x18\x03 \x01(\x05\x12\x12\n\nforce_host\x18\x04 \x01(\x05\x12\r\n\x05\x66ourk\x18\x05 \x01(\x05\"1\n\x05Popup\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\xca\x02\n\x0bRcmdArchive\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12=\n\x11\x63over_left_icon_1\x18\x03 \x01(\x0e\x32\".bilibili.app.dynamic.v2.CoverIcon\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x0e\n\x06is_pgc\x18\x06 \x01(\x08\x12\x0b\n\x03\x61id\x18\x07 \x01(\x03\x12\x31\n\x05\x62\x61\x64ge\x18\x08 \x01(\x0b\x32\".bilibili.app.dynamic.v2.IconBadge\x12\x18\n\x10\x63over_left_icon2\x18\t \x01(\x05\x12\x18\n\x10\x63over_left_text2\x18\n \x01(\t\x12\x18\n\x10\x63over_left_icon3\x18\x0b \x01(\x05\x12\x18\n\x10\x63over_left_text3\x18\x0c \x01(\t\"\x82\x01\n\nRcmdAuthor\x12\x31\n\x06\x61uthor\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x33\n\x08relation\x18\x03 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\"\x86\x01\n\x08RcmdItem\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.bilibili.app.dynamic.v2.RcmdType\x12<\n\x0crcmd_archive\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.RcmdArchiveH\x00\x42\x0b\n\trcmd_item\" \n\nRcmdOption\x12\x12\n\nshow_title\x18\x01 \x01(\x08\"*\n\rRcmdTopButton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\"\n\x0cRcmdUPsParam\x12\x12\n\ndislike_ts\x18\x01 \x01(\x03\"z\n\x08Relation\x12\x37\n\x06status\x18\x01 \x01(\x0e\x32\'.bilibili.app.dynamic.v2.RelationStatus\x12\x11\n\tis_follow\x18\x02 \x01(\x05\x12\x13\n\x0bis_followed\x18\x03 \x01(\x05\x12\r\n\x05title\x18\x04 \x01(\t\"\x9a\x01\n\rRepostListReq\x12\x12\n\ndynamic_id\x18\x01 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x02 \x01(\x03\x12\x0b\n\x03rid\x18\x03 \x01(\x03\x12\x0e\n\x06offset\x18\x04 \x01(\t\x12\x0c\n\x04\x66rom\x18\x05 \x01(\t\x12\x38\n\x0brepost_type\x18\x06 \x01(\x0e\x32#.bilibili.app.dynamic.v2.RepostType\"\xb4\x01\n\rRepostListRsp\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x13\n\x0btotal_count\x18\x04 \x01(\x03\x12\x38\n\x0brepost_type\x18\x05 \x01(\x0e\x32#.bilibili.app.dynamic.v2.RepostType\"T\n\x0fReactionListReq\x12\x12\n\ndynamic_id\x18\x01 \x01(\x03\x12\x10\n\x08\x64yn_type\x18\x02 \x01(\x03\x12\x0b\n\x03rid\x18\x03 \x01(\x03\x12\x0e\n\x06offset\x18\x04 \x01(\t\"}\n\x11ReactionListReply\x12\r\n\x05title\x18\x01 \x01(\t\x12\x37\n\x04list\x18\x02 \x03(\x0b\x32).bilibili.app.dynamic.v2.ReactionListItem\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x10\n\x08has_more\x18\x04 \x01(\x08\"\x9f\x01\n\x10ReactionListItem\x12/\n\x04user\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12\x33\n\x08relation\x18\x02 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12\x10\n\x08\x61\x63t_text\x18\x03 \x01(\t\x12\x13\n\x0brcmd_reason\x18\x04 \x01(\t\"J\n\x14SchoolRecommendReply\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32#.bilibili.app.dynamic.v2.CampusInfo\".\n\x12SchoolRecommendReq\x12\x0b\n\x03lat\x18\x01 \x01(\x02\x12\x0b\n\x03lng\x18\x02 \x01(\x02\"|\n\x11SchoolSearchReply\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32#.bilibili.app.dynamic.v2.CampusInfo\x12\x33\n\x05toast\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.SearchToast\"\"\n\x0fSchoolSearchReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\"\x97\x01\n\rSearchChannel\x12\r\n\x05title\x18\x01 \x01(\t\x12?\n\x0bmore_button\x18\x02 \x01(\x0b\x32*.bilibili.app.dynamic.v2.SearchTopicButton\x12\x36\n\x08\x63hannels\x18\x03 \x03(\x0b\x32$.bilibili.app.dynamic.v2.ChannelInfo\"\x93\x01\n\nSearchInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x32\n\x04list\x18\x02 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x10\n\x08track_id\x18\x03 \x01(\t\x12\r\n\x05total\x18\x04 \x01(\x03\x12\x10\n\x08has_more\x18\x05 \x01(\x08\x12\x0f\n\x07version\x18\x06 \x01(\t\"5\n\x0bSearchToast\x12\x12\n\ndesc_text1\x18\x01 \x01(\t\x12\x12\n\ndesc_text2\x18\x02 \x01(\t\"\x96\x01\n\x0bSearchTopic\x12\r\n\x05title\x18\x01 \x01(\t\x12?\n\x0bmore_button\x18\x02 \x01(\x0b\x32*.bilibili.app.dynamic.v2.SearchTopicButton\x12\x37\n\x05items\x18\x03 \x03(\x0b\x32(.bilibili.app.dynamic.v2.SearchTopicItem\"4\n\x11SearchTopicButton\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08jump_uri\x18\x02 \x01(\t\"g\n\x0fSearchTopicItem\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x12\n\ntopic_name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x13\n\x0bis_activity\x18\x05 \x01(\x08\" \n\x0eSetDecisionReq\x12\x0e\n\x06result\x18\x01 \x01(\x05\"<\n\x12SetRecentCampusReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\"t\n\x0cShareChannel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\t\x12\x36\n\x07reserve\x18\x04 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ShareReserve\"\xaa\x01\n\x0cShareReserve\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x14\n\x0cqr_code_icon\x18\x03 \x01(\t\x12\x14\n\x0cqr_code_text\x18\x04 \x01(\t\x12\x13\n\x0bqr_code_url\x18\x05 \x01(\t\x12<\n\tuser_info\x18\x06 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionUserInfo\"5\n\x08SortType\x12\x11\n\tsort_type\x18\x01 \x01(\x05\x12\x16\n\x0esort_type_name\x18\x02 \x01(\t\"n\n\x0cStoryArchive\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x35\n\tdimension\x18\x04 \x01(\x0b\x32\".bilibili.app.dynamic.v2.Dimension\"\xb7\x01\n\tStoryItem\x12\x31\n\x06\x61uthor\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\x03\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12>\n\rstory_archive\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.StoryArchiveH\x00\x42\x0b\n\trcmd_item\"<\n\x12SubscribeCampusReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\"\xc1\x01\n\x13ThreePointAttention\x12\x16\n\x0e\x61ttention_icon\x18\x01 \x01(\t\x12\x16\n\x0e\x61ttention_text\x18\x02 \x01(\t\x12\x1a\n\x12not_attention_icon\x18\x03 \x01(\t\x12\x1a\n\x12not_attention_text\x18\x04 \x01(\t\x12\x42\n\x06status\x18\x05 \x01(\x0e\x32\x32.bilibili.app.dynamic.v2.ThreePointAttentionStatus\"\xe2\x01\n\x12ThreePointAutoPlay\x12\x11\n\topen_icon\x18\x01 \x01(\t\x12\x11\n\topen_text\x18\x02 \x01(\t\x12\x12\n\nclose_icon\x18\x03 \x01(\t\x12\x12\n\nclose_text\x18\x04 \x01(\t\x12\x14\n\x0copen_text_v2\x18\x05 \x01(\t\x12\x15\n\rclose_text_v2\x18\x06 \x01(\t\x12\x11\n\tonly_icon\x18\x07 \x01(\t\x12\x11\n\tonly_text\x18\x08 \x01(\t\x12\x14\n\x0copen_icon_v2\x18\t \x01(\t\x12\x15\n\rclose_icon_v2\x18\n \x01(\t\"\xa8\x01\n\x11ThreePointComment\x12<\n\x0cup_selection\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.CommentDetail\x12\x38\n\x08up_close\x18\x02 \x01(\x0b\x32&.bilibili.app.dynamic.v2.CommentDetail\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\"\x89\x01\n\x11ThreePointDefault\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12>\n\x05toast\x18\x05 \x01(\x0b\x32/.bilibili.app.dynamic.v2.ThreePointDefaultToast\"5\n\x16ThreePointDefaultToast\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"0\n\x11ThreePointDislike\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"~\n\x12ThreePointFavorite\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x03\x12\x14\n\x0cis_favourite\x18\x04 \x01(\x08\x12\x13\n\x0b\x63\x61ncel_icon\x18\x05 \x01(\t\x12\x14\n\x0c\x63\x61ncel_title\x18\x06 \x01(\t\"\x9d\x01\n\x0eThreePointHide\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12G\n\x0binteractive\x18\x03 \x01(\x0b\x32\x32.bilibili.app.dynamic.v2.ThreePointHideInteractive\x12\x11\n\tblook_fid\x18\x04 \x01(\x03\x12\x12\n\nblook_type\x18\x05 \x01(\t\"Z\n\x19ThreePointHideInteractive\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63onfirm\x18\x02 \x01(\t\x12\x0e\n\x06\x63\x61ncel\x18\x03 \x01(\t\x12\r\n\x05toast\x18\x04 \x01(\t\"\x88\x06\n\x0eThreePointItem\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.bilibili.app.dynamic.v2.ThreePointType\x12=\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\x0b\x32*.bilibili.app.dynamic.v2.ThreePointDefaultH\x00\x12\x42\n\x0b\x61uto_player\x18\x03 \x01(\x0b\x32+.bilibili.app.dynamic.v2.ThreePointAutoPlayH\x00\x12\x39\n\x05share\x18\x04 \x01(\x0b\x32(.bilibili.app.dynamic.v2.ThreePointShareH\x00\x12\x41\n\tattention\x18\x05 \x01(\x0b\x32,.bilibili.app.dynamic.v2.ThreePointAttentionH\x00\x12\x37\n\x04wait\x18\x06 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointWaitH\x00\x12=\n\x07\x64islike\x18\x07 \x01(\x0b\x32*.bilibili.app.dynamic.v2.ThreePointDislikeH\x00\x12?\n\x08\x66\x61vorite\x18\x08 \x01(\x0b\x32+.bilibili.app.dynamic.v2.ThreePointFavoriteH\x00\x12\x35\n\x03top\x18\t \x01(\x0b\x32&.bilibili.app.dynamic.v2.ThreePointTopH\x00\x12=\n\x07\x63omment\x18\n \x01(\x0b\x32*.bilibili.app.dynamic.v2.ThreePointCommentH\x00\x12\x37\n\x04hide\x18\x0b \x01(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointHideH\x00\x12N\n\x10topic_irrelevant\x18\x0c \x01(\x0b\x32\x32.bilibili.app.dynamic.v2.ThreePointTopicIrrelevantH\x00\x42\x06\n\x04item\"\xbe\x01\n\x0fThreePointShare\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12@\n\x07\x63hannel\x18\x03 \x03(\x0b\x32/.bilibili.app.dynamic.v2.ThreePointShareChannel\x12\x14\n\x0c\x63hannel_name\x18\x04 \x01(\t\x12\x36\n\x07reserve\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ShareReserve\"5\n\x16ThreePointShareChannel\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"\\\n\rThreePointTop\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12.\n\x04type\x18\x03 \x01(\x0e\x32 .bilibili.app.dynamic.v2.TopType\"\x8b\x01\n\x19ThreePointTopicIrrelevant\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05toast\x18\x03 \x01(\t\x12\x10\n\x08topic_id\x18\x04 \x01(\x03\x12\x0e\n\x06res_id\x18\x05 \x01(\x03\x12\x10\n\x08res_type\x18\x06 \x01(\x03\x12\x0e\n\x06reason\x18\x07 \x01(\t\"~\n\x0eThreePointWait\x12\x15\n\raddition_icon\x18\x01 \x01(\t\x12\x15\n\raddition_text\x18\x02 \x01(\t\x12\x18\n\x10no_addition_icon\x18\x03 \x01(\t\x12\x18\n\x10no_addition_text\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\x03\"R\n\rTopAdditionUP\x12/\n\x02up\x18\x01 \x03(\x0b\x32#.bilibili.app.dynamic.v2.AdditionUP\x12\x10\n\x08has_fold\x18\x02 \x01(\x05\"M\n\x0bTopicButton\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x10\n\x08jump_uri\x18\x03 \x01(\t\x12\x0f\n\x07red_dot\x18\x04 \x01(\x08\"n\n\tTopicItem\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x12\n\ntopic_name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\r\n\x05\x64\x65sc2\x18\x05 \x01(\t\x12\x11\n\trcmd_desc\x18\x06 \x01(\t\"\xe5\x01\n\tTopicList\x12\r\n\x05title\x18\x01 \x01(\t\x12?\n\x0ftopic_list_item\x18\x02 \x03(\x0b\x32&.bilibili.app.dynamic.v2.TopicListItem\x12\x38\n\nact_button\x18\x03 \x01(\x0b\x32$.bilibili.app.dynamic.v2.TopicButton\x12\x39\n\x0bmore_button\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.TopicButton\x12\x13\n\x0bserver_info\x18\x05 \x01(\t\"\xd7\x01\n\rTopicListItem\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x12\n\nicon_title\x18\x02 \x01(\t\x12\x10\n\x08topic_id\x18\x03 \x01(\x03\x12\x12\n\ntopic_name\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x0b\n\x03pos\x18\x06 \x01(\x03\x12\x13\n\x0bserver_info\x18\x07 \x01(\t\x12\x15\n\rhead_icon_url\x18\x08 \x01(\t\x12\x0e\n\x06up_mid\x18\t \x01(\x03\x12\x15\n\rtail_icon_url\x18\n \x01(\t\x12\x11\n\textension\x18\x0b \x01(\t\"e\n\x0eTopicListReply\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.dynamic.v2.TopicItem\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x0e\n\x06offset\x18\x03 \x01(\t\"1\n\x0cTopicListReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\"\xab\x01\n\rTopicRcmdCard\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x12\n\ntopic_name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x34\n\x06\x62utton\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\r\n\x05\x64\x65sc1\x18\x05 \x01(\t\x12\r\n\x05\x64\x65sc2\x18\x06 \x01(\t\x12\x13\n\x0bupdate_desc\x18\x07 \x01(\t\"\x8c\x01\n\x0fTopicSquareInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x34\n\x06\x62utton\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\x34\n\x04rcmd\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.TopicRcmdCard\"J\n\x10TopicSquareReply\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.bilibili.app.dynamic.v2.TopicSquareInfo\"#\n\x0eTopicSquareReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\"c\n\x08Unfollow\x12\r\n\x05title\x18\x01 \x01(\t\x12\x37\n\x04list\x18\x02 \x03(\x0b\x32).bilibili.app.dynamic.v2.UnfollowUserItem\x12\x0f\n\x07TrackId\x18\x03 \x01(\t\"\xe3\x02\n\x10UnfollowUserItem\x12\x12\n\nhas_update\x18\x01 \x01(\x08\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\x12\x0b\n\x03pos\x18\x05 \x01(\x05\x12\x36\n\nlive_state\x18\x06 \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\x12\x39\n\x08official\x18\x07 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.OfficialVerify\x12-\n\x03vip\x18\x08 \x01(\x0b\x32 .bilibili.app.dynamic.v2.VipInfo\x12\x0c\n\x04sign\x18\t \x01(\t\x12\r\n\x05label\x18\n \x01(\t\x12\x39\n\x06\x62utton\x18\x0b \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x0b\n\x03uri\x18\x0c \x01(\t\"\x9a\x03\n\nUpListItem\x12\x12\n\nhas_update\x18\x01 \x01(\x08\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\x12\x0b\n\x03pos\x18\x05 \x01(\x03\x12=\n\x0euser_item_type\x18\x06 \x01(\x0e\x32%.bilibili.app.dynamic.v2.UserItemType\x12\x41\n\x11\x64isplay_style_day\x18\x07 \x01(\x0b\x32&.bilibili.app.dynamic.v2.UserItemStyle\x12\x43\n\x13\x64isplay_style_night\x18\x08 \x01(\x0b\x32&.bilibili.app.dynamic.v2.UserItemStyle\x12\x10\n\x08style_id\x18\t \x01(\x03\x12\x36\n\nlive_state\x18\n \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\x12\x11\n\tseparator\x18\x0b \x01(\x08\x12\x0b\n\x03uri\x18\x0c \x01(\t\x12\x11\n\tis_recall\x18\r \x01(\x08\"-\n\x0fUpListMoreLabel\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\x8e\x03\n\x08UserInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x39\n\x08official\x18\x04 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.OfficialVerify\x12-\n\x03vip\x18\x05 \x01(\x0b\x32 .bilibili.app.dynamic.v2.VipInfo\x12/\n\x04live\x18\x06 \x01(\x0b\x32!.bilibili.app.dynamic.v2.LiveInfo\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x35\n\x07pendant\x18\x08 \x01(\x0b\x32$.bilibili.app.dynamic.v2.UserPendant\x12\x35\n\tnameplate\x18\t \x01(\x0b\x32\".bilibili.app.dynamic.v2.Nameplate\x12\r\n\x05level\x18\n \x01(\x05\x12\x0c\n\x04sign\x18\x0b \x01(\t\x12\x10\n\x08\x66\x61\x63\x65_nft\x18\x0c \x01(\x05\x12\x14\n\x0c\x66\x61\x63\x65_nft_new\x18\r \x01(\x05\"~\n\rUserItemStyle\x12\x11\n\trect_text\x18\x01 \x01(\t\x12\x17\n\x0frect_text_color\x18\x02 \x01(\t\x12\x11\n\trect_icon\x18\x03 \x01(\t\x12\x15\n\rrect_bg_color\x18\x04 \x01(\t\x12\x17\n\x0fouter_animation\x18\x05 \x01(\t\"G\n\x0bUserPendant\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0e\n\x06\x65xpire\x18\x04 \x01(\x03\"\xe0\x01\n\nVideoBadge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\x12\x10\n\x08\x62g_alpha\x18\t \x01(\x05\x12\x16\n\x0e\x62g_alpha_night\x18\n \x01(\x05\"\xb1\x01\n\x07VipInfo\x12\x0c\n\x04Type\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x03 \x01(\x03\x12\x30\n\x05label\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v2.VipLabel\x12\x12\n\ntheme_type\x18\x05 \x01(\x05\x12\x18\n\x10\x61vatar_subscript\x18\x06 \x01(\x05\x12\x16\n\x0enickname_color\x18\x07 \x01(\t\";\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x13\n\x0blabel_theme\x18\x03 \x01(\t\"Y\n\x06Weight\x12\r\n\x05title\x18\x01 \x01(\t\x12\x32\n\x05items\x18\x02 \x03(\x0b\x32#.bilibili.app.dynamic.v2.WeightItem\x12\x0c\n\x04icon\x18\x03 \x01(\t\"/\n\x0cWeightButton\x12\x10\n\x08jump_url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"6\n\rWeightDislike\x12\x16\n\x0e\x66\x65\x65\x64_back_type\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"\xbb\x01\n\nWeightItem\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.bilibili.app.dynamic.v2.WeightType\x12\x37\n\x06\x62utton\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.WeightButtonH\x00\x12\x39\n\x07\x64islike\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.WeightDislikeH\x00\x42\x06\n\x04item*2\n\x10\x41\x64\x64\x42uttonBgStyle\x12\x08\n\x04\x66ill\x10\x00\x12\n\n\x06stroke\x10\x01\x12\x08\n\x04gray\x10\x02*8\n\rAddButtonType\x12\x0b\n\x07\x62t_none\x10\x00\x12\x0b\n\x07\x62t_jump\x10\x01\x12\r\n\tbt_button\x10\x02*n\n\x11\x41\x64\x64itionVoteState\x12\x1c\n\x18\x61\x64\x64ition_vote_state_none\x10\x00\x12\x1c\n\x18\x61\x64\x64ition_vote_state_open\x10\x01\x12\x1d\n\x19\x61\x64\x64ition_vote_state_close\x10\x02*\x88\x01\n\x10\x41\x64\x64itionVoteType\x12\x1b\n\x17\x61\x64\x64ition_vote_type_none\x10\x00\x12\x1b\n\x17\x61\x64\x64ition_vote_type_word\x10\x01\x12\x1a\n\x16\x61\x64\x64ition_vote_type_pic\x10\x02\x12\x1e\n\x1a\x61\x64\x64ition_vote_type_default\x10\x03*9\n\x19\x41\x64\x64itionalButtonClickType\x12\x0e\n\nclick_none\x10\x00\x12\x0c\n\x08\x63lick_up\x10\x01*:\n\x16\x41\x64\x64itionalButtonStatus\x12\x08\n\x04none\x10\x00\x12\x0b\n\x07uncheck\x10\x01\x12\t\n\x05\x63heck\x10\x02*3\n\x17\x41\x64\x64itionalShareShowType\x12\x0b\n\x07st_none\x10\x00\x12\x0b\n\x07st_show\x10\x01*\x85\x02\n\x0e\x41\x64\x64itionalType\x12\x13\n\x0f\x61\x64\x64itional_none\x10\x00\x12\x17\n\x13\x61\x64\x64itional_type_pgc\x10\x01\x12\x19\n\x15\x61\x64\x64itional_type_goods\x10\x02\x12\x18\n\x14\x61\x64\x64itional_type_vote\x10\x03\x12\x1a\n\x16\x61\x64\x64itional_type_common\x10\x04\x12\x1a\n\x16\x61\x64\x64itional_type_esport\x10\x05\x12\x1b\n\x17\x61\x64\x64itional_type_up_rcmd\x10\x06\x12\x17\n\x13\x61\x64\x64itional_type_ugc\x10\x07\x12\"\n\x1e\x61\x64\x64itional_type_up_reservation\x10\x08*\x83\x01\n\rCampusTabType\x12\x0f\n\x0b\x63\x61mpus_none\x10\x00\x12\x11\n\rcampus_school\x10\x01\x12\x12\n\x0e\x63\x61mpus_dynamic\x10\x02\x12\x12\n\x0e\x63\x61mpus_account\x10\x03\x12\x14\n\x10\x63\x61mpus_billboard\x10\x04\x12\x10\n\x0c\x63\x61mpus_topic\x10\x05*5\n\tCoverIcon\x12\x13\n\x0f\x63over_icon_none\x10\x00\x12\x13\n\x0f\x63over_icon_play\x10\x01*\x94\x03\n\x08\x44\x65scType\x12\x12\n\x0e\x64\x65sc_type_none\x10\x00\x12\x12\n\x0e\x64\x65sc_type_text\x10\x01\x12\x12\n\x0e\x64\x65sc_type_aite\x10\x02\x12\x15\n\x11\x64\x65sc_type_lottery\x10\x03\x12\x12\n\x0e\x64\x65sc_type_vote\x10\x04\x12\x13\n\x0f\x64\x65sc_type_topic\x10\x05\x12\x13\n\x0f\x64\x65sc_type_goods\x10\x06\x12\x10\n\x0c\x64\x65sc_type_bv\x10\x07\x12\x10\n\x0c\x64\x65sc_type_av\x10\x08\x12\x13\n\x0f\x64\x65sc_type_emoji\x10\t\x12\x12\n\x0e\x64\x65sc_type_user\x10\n\x12\x10\n\x0c\x64\x65sc_type_cv\x10\x0b\x12\x10\n\x0c\x64\x65sc_type_vc\x10\x0c\x12\x11\n\rdesc_type_web\x10\r\x12\x14\n\x10\x64\x65sc_type_taobao\x10\x0e\x12\x12\n\x0e\x64\x65sc_type_mail\x10\x0f\x12\x18\n\x14\x64\x65sc_type_ogv_season\x10\x10\x12\x14\n\x10\x64\x65sc_type_ogv_ep\x10\x11\x12\x19\n\x15\x64\x65sc_type_search_word\x10\x12*\'\n\x0c\x44isableState\x12\r\n\thighlight\x10\x00\x12\x08\n\x04gary\x10\x01*\xe5\x01\n\rDynExtendType\x12\x15\n\x11\x64yn_ext_type_none\x10\x00\x12\x16\n\x12\x64yn_ext_type_topic\x10\x01\x12\x14\n\x10\x64yn_ext_type_lbs\x10\x02\x12\x14\n\x10\x64yn_ext_type_hot\x10\x03\x12\x15\n\x11\x64yn_ext_type_game\x10\x04\x12\x17\n\x13\x64yn_ext_type_common\x10\x05\x12\x18\n\x14\x64yn_ext_type_biliCut\x10\x06\x12\x14\n\x10\x64yn_ext_type_ogv\x10\x07\x12\x19\n\x15\x64yn_ext_type_auto_ogv\x10\x08*\xc9\x04\n\rDynModuleType\x12\x0f\n\x0bmodule_none\x10\x00\x12\x11\n\rmodule_author\x10\x01\x12\x12\n\x0emodule_dispute\x10\x02\x12\x0f\n\x0bmodule_desc\x10\x03\x12\x12\n\x0emodule_dynamic\x10\x04\x12\x12\n\x0emodule_forward\x10\x05\x12\x13\n\x0fmodule_likeUser\x10\x06\x12\x11\n\rmodule_extend\x10\x07\x12\x15\n\x11module_additional\x10\x08\x12\x0f\n\x0bmodule_stat\x10\t\x12\x0f\n\x0bmodule_fold\x10\n\x12\x12\n\x0emodule_comment\x10\x0b\x12\x16\n\x12module_interaction\x10\x0c\x12\x19\n\x15module_author_forward\x10\r\x12\r\n\tmodule_ad\x10\x0e\x12\x11\n\rmodule_banner\x10\x0f\x12\x14\n\x10module_item_null\x10\x10\x12\x15\n\x11module_share_info\x10\x11\x12\x14\n\x10module_recommend\x10\x12\x12\x17\n\x13module_stat_forward\x10\x13\x12\x0e\n\nmodule_top\x10\x14\x12\x11\n\rmodule_bottom\x10\x15\x12\x10\n\x0cmodule_story\x10\x16\x12\x10\n\x0cmodule_topic\x10\x17\x12\x1c\n\x18module_topic_details_ext\x10\x18\x12\x12\n\x0emodule_top_tag\x10\x19\x12\x16\n\x12module_topic_brief\x10\x1a\x12\x10\n\x0cmodule_title\x10\x1b*U\n\nDynUriType\x12\x15\n\x11\x64yn_uri_type_none\x10\x00\x12\x17\n\x13\x64yn_uri_type_direct\x10\x01\x12\x17\n\x13\x64yn_uri_type_suffix\x10\x02*\xd3\x02\n\x0b\x44ynamicType\x12\x0c\n\x08\x64yn_none\x10\x00\x12\x0b\n\x07\x66orward\x10\x01\x12\x06\n\x02\x61v\x10\x02\x12\x07\n\x03pgc\x10\x03\x12\x0b\n\x07\x63ourses\x10\x04\x12\x08\n\x04\x66old\x10\x05\x12\x08\n\x04word\x10\x06\x12\x08\n\x04\x64raw\x10\x07\x12\x0b\n\x07\x61rticle\x10\x08\x12\t\n\x05music\x10\t\x12\x11\n\rcommon_square\x10\n\x12\x13\n\x0f\x63ommon_vertical\x10\x0b\x12\x08\n\x04live\x10\x0c\x12\r\n\tmedialist\x10\r\x12\x12\n\x0e\x63ourses_season\x10\x0e\x12\x06\n\x02\x61\x64\x10\x0f\x12\n\n\x06\x61pplet\x10\x10\x12\x10\n\x0csubscription\x10\x11\x12\r\n\tlive_rcmd\x10\x12\x12\n\n\x06\x62\x61nner\x10\x13\x12\x0e\n\nugc_season\x10\x14\x12\x14\n\x10subscription_new\x10\x15\x12\t\n\x05story\x10\x16\x12\x0e\n\ntopic_rcmd\x10\x17*B\n\tEmojiType\x12\x0e\n\nemoji_none\x10\x00\x12\r\n\temoji_old\x10\x01\x12\r\n\temoji_new\x10\x02\x12\x07\n\x03vip\x10\x03*\x17\n\x0b\x45spaceStyle\x12\x08\n\x04moba\x10\x00*m\n\x08\x46oldType\x12\x10\n\x0c\x46oldTypeZore\x10\x00\x12\x13\n\x0f\x46oldTypePublish\x10\x01\x12\x14\n\x10\x46oldTypeFrequent\x10\x02\x12\x11\n\rFoldTypeUnite\x10\x03\x12\x11\n\rFoldTypeLimit\x10\x04*.\n\nFollowType\x12\x11\n\rft_not_follow\x10\x00\x12\r\n\tft_follow\x10\x01*9\n\x12HighlightTextStyle\x12\x0e\n\nstyle_none\x10\x00\x12\x13\n\x0fstyle_highlight\x10\x01*:\n\nImageStyle\x12\x16\n\x12\x61\x64\x64_style_vertical\x10\x00\x12\x14\n\x10\x61\x64\x64_style_square\x10\x01*1\n\rLightFromType\x12\x0e\n\nfrom_login\x10\x00\x12\x10\n\x0c\x66rom_unlogin\x10\x01*<\n\tLiveState\x12\r\n\tlive_none\x10\x00\x12\r\n\tlive_live\x10\x01\x12\x11\n\rlive_rotation\x10\x02*<\n\rLocalIconType\x12\x16\n\x12local_icon_comment\x10\x00\x12\x13\n\x0flocal_icon_like\x10\x01*b\n\x10MdlDynCommonType\x12\x17\n\x13mdl_dyn_common_none\x10\x00\x12\x19\n\x15mdl_dyn_common_square\x10\x01\x12\x1a\n\x16mdl_dyn_common_vertica\x10\x02*\xa0\x01\n\x11MdlDynDrawTagType\x12\x15\n\x11mdl_draw_tag_none\x10\x00\x12\x17\n\x13mdl_draw_tag_common\x10\x01\x12\x16\n\x12mdl_draw_tag_goods\x10\x02\x12\x15\n\x11mdl_draw_tag_user\x10\x03\x12\x16\n\x12mdl_draw_tag_topic\x10\x04\x12\x14\n\x10mdl_draw_tag_lbs\x10\x05*\x97\x01\n\x1aMdlDynSubscriptionNewStyle\x12\'\n#mdl_dyn_subscription_new_style_nont\x10\x00\x12\'\n#mdl_dyn_subscription_new_style_live\x10\x01\x12\'\n#mdl_dyn_subscription_new_style_draw\x10\x02*g\n\tMediaType\x12\x11\n\rMediaTypeNone\x10\x00\x12\x10\n\x0cMediaTypeUGC\x10\x01\x12\x10\n\x0cMediaTypePGC\x10\x02\x12\x11\n\rMediaTypeLive\x10\x03\x12\x10\n\x0cMediaTypeVCS\x10\x04*\xad\x01\n\x15ModuleAuthorBadgeType\x12!\n\x1dmodule_author_badge_type_none\x10\x00\x12\'\n#module_author_badge_type_threePoint\x10\x01\x12#\n\x1fmodule_author_badge_type_button\x10\x02\x12#\n\x1fmodule_author_badge_type_weight\x10\x03*L\n\x10ModuleBannerType\x12\x1b\n\x17module_banner_type_none\x10\x00\x12\x1b\n\x17module_banner_type_user\x10\x01*\xf1\x02\n\x11ModuleDynamicType\x12\x13\n\x0fmdl_dyn_archive\x10\x00\x12\x0f\n\x0bmdl_dyn_pgc\x10\x01\x12\x17\n\x13mdl_dyn_cour_season\x10\x02\x12\x16\n\x12mdl_dyn_cour_batch\x10\x03\x12\x13\n\x0fmdl_dyn_forward\x10\x04\x12\x10\n\x0cmdl_dyn_draw\x10\x05\x12\x13\n\x0fmdl_dyn_article\x10\x06\x12\x11\n\rmdl_dyn_music\x10\x07\x12\x12\n\x0emdl_dyn_common\x10\x08\x12\x10\n\x0cmdl_dyn_live\x10\t\x12\x15\n\x11mdl_dyn_medialist\x10\n\x12\x12\n\x0emdl_dyn_applet\x10\x0b\x12\x18\n\x14mdl_dyn_subscription\x10\x0c\x12\x15\n\x11mdl_dyn_live_rcmd\x10\r\x12\x16\n\x12mdl_dyn_ugc_season\x10\x0e\x12\x1c\n\x18mdl_dyn_subscription_new\x10\x0f*^\n\x0bNetworkType\x12\x0e\n\nNT_UNKNOWN\x10\x00\x12\x08\n\x04WIFI\x10\x01\x12\x0c\n\x08\x43\x45LLULAR\x10\x02\x12\x0b\n\x07OFFLINE\x10\x03\x12\x0c\n\x08OTHERNET\x10\x04\x12\x0c\n\x08\x45THERNET\x10\x05*.\n\x08RcmdType\x12\x10\n\x0crcmd_archive\x10\x00\x12\x10\n\x0crcmd_dynamic\x10\x01*/\n\x07Refresh\x12\x0f\n\x0brefresh_new\x10\x00\x12\x13\n\x0frefresh_history\x10\x01*\xc3\x01\n\x0eRelationStatus\x12\x18\n\x14relation_status_none\x10\x00\x12\x1c\n\x18relation_status_nofollow\x10\x01\x12\x1a\n\x16relation_status_follow\x10\x02\x12\x1c\n\x18relation_status_followed\x10\x03\x12\"\n\x1erelation_status_mutual_concern\x10\x04\x12\x1b\n\x17relation_status_special\x10\x05*0\n\nRepostType\x12\x0e\n\nrepost_hot\x10\x00\x12\x12\n\x0erepost_general\x10\x01*o\n\x1aReserveRelationLotteryType\x12)\n%reserve_relation_lottery_type_default\x10\x00\x12&\n\"reserve_relation_lottery_type_cron\x10\x01*3\n\x0bReserveType\x12\x10\n\x0creserve_none\x10\x00\x12\x12\n\x0ereserve_recall\x10\x01*4\n\x08ShowType\x12\x12\n\x0eshow_type_none\x10\x00\x12\x14\n\x10show_type_backup\x10\x01*L\n\tStyleType\x12\x13\n\x0fSTYLE_TYPE_NONE\x10\x00\x12\x13\n\x0fSTYLE_TYPE_LIVE\x10\x01\x12\x15\n\x11STYLE_TYPE_DYN_UP\x10\x02*M\n\x06TFType\x12\n\n\x06U_CARD\x10\x00\x12\t\n\x05U_PKG\x10\x01\x12\n\n\x06\x43_CARD\x10\x02\x12\t\n\x05\x43_PKG\x10\x03\x12\n\n\x06T_CARD\x10\x04\x12\t\n\x05T_PKG\x10\x05*C\n\x19ThreePointAttentionStatus\x12\x14\n\x10tp_not_attention\x10\x00\x12\x10\n\x0ctp_attention\x10\x01*\xdc\x01\n\x0eThreePointType\x12\x0b\n\x07tp_none\x10\x00\x12\x0e\n\nbackground\x10\x01\x12\r\n\tauto_play\x10\x02\x12\t\n\x05share\x10\x03\x12\x08\n\x04wait\x10\x04\x12\r\n\tattention\x10\x05\x12\n\n\x06report\x10\x06\x12\n\n\x06\x64\x65lete\x10\x07\x12\x0b\n\x07\x64islike\x10\x08\x12\x0c\n\x08\x66\x61vorite\x10\t\x12\x07\n\x03top\x10\n\x12\x0b\n\x07\x63omment\x10\x0b\x12\x08\n\x04hide\x10\x0c\x12\x11\n\rcampus_delete\x10\r\x12\x14\n\x10topic_irrelevant\x10\x0e*\"\n\tThumbType\x12\n\n\x06\x63\x61ncel\x10\x00\x12\t\n\x05thumb\x10\x01*\'\n\x07TopType\x12\x0c\n\x08top_none\x10\x00\x12\x0e\n\ntop_cancel\x10\x01*\x96\x01\n\x0cUserItemType\x12\x17\n\x13user_item_type_none\x10\x00\x12\x17\n\x13user_item_type_live\x10\x01\x12\x1e\n\x1auser_item_type_live_custom\x10\x02\x12\x19\n\x15user_item_type_normal\x10\x03\x12\x19\n\x15user_item_type_extend\x10\x04*\xa5\x01\n\x0cVideoSubType\x12\x14\n\x10VideoSubTypeNone\x10\x00\x12\x17\n\x13VideoSubTypeBangumi\x10\x01\x12\x15\n\x11VideoSubTypeMovie\x10\x02\x12\x1b\n\x17VideoSubTypeDocumentary\x10\x03\x12\x18\n\x14VideoSubTypeDomestic\x10\x04\x12\x18\n\x14VideoSubTypeTeleplay\x10\x05*j\n\tVideoType\x12\x16\n\x12video_type_general\x10\x00\x12\x16\n\x12video_type_dynamic\x10\x01\x12\x17\n\x13video_type_playback\x10\x02\x12\x14\n\x10video_type_story\x10\x03*\'\n\nVoteStatus\x12\n\n\x06normal\x10\x00\x12\r\n\tanonymous\x10\x01*B\n\nWeightType\x12\x0f\n\x0bweight_none\x10\x00\x12\x12\n\x0eweight_dislike\x10\x01\x12\x0f\n\x0bweight_jump\x10\x02\x32\xf7!\n\x07\x44ynamic\x12X\n\x08\x44ynVideo\x12$.bilibili.app.dynamic.v2.DynVideoReq\x1a&.bilibili.app.dynamic.v2.DynVideoReply\x12R\n\x06\x44ynAll\x12\".bilibili.app.dynamic.v2.DynAllReq\x1a$.bilibili.app.dynamic.v2.DynAllReply\x12^\n\nDynDetails\x12&.bilibili.app.dynamic.v2.DynDetailsReq\x1a(.bilibili.app.dynamic.v2.DynDetailsReply\x12p\n\x10\x44ynVideoPersonal\x12,.bilibili.app.dynamic.v2.DynVideoPersonalReq\x1a..bilibili.app.dynamic.v2.DynVideoPersonalReply\x12\x64\n\x11\x44ynVideoUpdOffset\x12-.bilibili.app.dynamic.v2.DynVideoUpdOffsetReq\x1a .bilibili.app.dynamic.v2.NoReply\x12\x85\x01\n\x17\x44ynAdditionCommonFollow\x12\x33.bilibili.app.dynamic.v2.DynAdditionCommonFollowReq\x1a\x35.bilibili.app.dynamic.v2.DynAdditionCommonFollowReply\x12R\n\x08\x44ynThumb\x12$.bilibili.app.dynamic.v2.DynThumbReq\x1a .bilibili.app.dynamic.v2.NoReply\x12\x61\n\x0b\x44ynFakeCard\x12\'.bilibili.app.dynamic.v2.DynFakeCardReq\x1a).bilibili.app.dynamic.v2.DynFakeCardReply\x12s\n\x11\x44ynRcmdUpExchange\x12-.bilibili.app.dynamic.v2.DynRcmdUpExchangeReq\x1a/.bilibili.app.dynamic.v2.DynRcmdUpExchangeReply\x12j\n\x0e\x44ynAllPersonal\x12*.bilibili.app.dynamic.v2.DynAllPersonalReq\x1a,.bilibili.app.dynamic.v2.DynAllPersonalReply\x12`\n\x0f\x44ynAllUpdOffset\x12+.bilibili.app.dynamic.v2.DynAllUpdOffsetReq\x1a .bilibili.app.dynamic.v2.NoReply\x12U\n\x07\x44ynVote\x12#.bilibili.app.dynamic.v2.DynVoteReq\x1a%.bilibili.app.dynamic.v2.DynVoteReply\x12|\n\x14\x44ynMixUpListViewMore\x12\x30.bilibili.app.dynamic.v2.DynMixUpListViewMoreReq\x1a\x32.bilibili.app.dynamic.v2.DynMixUpListViewMoreReply\x12X\n\x08\x44ynLight\x12$.bilibili.app.dynamic.v2.DynLightReq\x1a&.bilibili.app.dynamic.v2.DynLightReply\x12[\n\tDynDetail\x12%.bilibili.app.dynamic.v2.DynDetailReq\x1a\'.bilibili.app.dynamic.v2.DynDetailReply\x12X\n\x08LikeList\x12$.bilibili.app.dynamic.v2.LikeListReq\x1a&.bilibili.app.dynamic.v2.LikeListReply\x12\\\n\nRepostList\x12&.bilibili.app.dynamic.v2.RepostListReq\x1a&.bilibili.app.dynamic.v2.RepostListRsp\x12\x64\n\x0cReactionList\x12(.bilibili.app.dynamic.v2.ReactionListReq\x1a*.bilibili.app.dynamic.v2.ReactionListReply\x12V\n\x08\x44ynSpace\x12$.bilibili.app.dynamic.v2.DynSpaceReq\x1a$.bilibili.app.dynamic.v2.DynSpaceRsp\x12\\\n\x0e\x44ynUnLoginRcmd\x12#.bilibili.app.dynamic.v2.DynRcmdReq\x1a%.bilibili.app.dynamic.v2.DynRcmdReply\x12p\n\x10\x44ynServerDetails\x12,.bilibili.app.dynamic.v2.DynServerDetailsReq\x1a..bilibili.app.dynamic.v2.DynServerDetailsReply\x12[\n\tDynSearch\x12%.bilibili.app.dynamic.v2.DynSearchReq\x1a\'.bilibili.app.dynamic.v2.DynSearchReply\x12X\n\x0bSetDecision\x12\'.bilibili.app.dynamic.v2.SetDecisionReq\x1a .bilibili.app.dynamic.v2.NoReply\x12j\n\x0e\x41lumniDynamics\x12*.bilibili.app.dynamic.v2.AlumniDynamicsReq\x1a,.bilibili.app.dynamic.v2.AlumniDynamicsReply\x12^\n\nCampusRcmd\x12&.bilibili.app.dynamic.v2.CampusRcmdReq\x1a(.bilibili.app.dynamic.v2.CampusRcmdReply\x12`\n\x0fSubscribeCampus\x12+.bilibili.app.dynamic.v2.SubscribeCampusReq\x1a .bilibili.app.dynamic.v2.NoReply\x12`\n\x0fSetRecentCampus\x12+.bilibili.app.dynamic.v2.SetRecentCampusReq\x1a .bilibili.app.dynamic.v2.NoReply\x12R\n\x06\x44ynTab\x12\".bilibili.app.dynamic.v2.DynTabReq\x1a$.bilibili.app.dynamic.v2.DynTabReply\x12\x64\n\x0cSchoolSearch\x12(.bilibili.app.dynamic.v2.SchoolSearchReq\x1a*.bilibili.app.dynamic.v2.SchoolSearchReply\x12m\n\x0fSchoolRecommend\x12+.bilibili.app.dynamic.v2.SchoolRecommendReq\x1a-.bilibili.app.dynamic.v2.SchoolRecommendReply\x12\x7f\n\x15\x44ynSpaceSearchDetails\x12\x31.bilibili.app.dynamic.v2.DynSpaceSearchDetailsReq\x1a\x33.bilibili.app.dynamic.v2.DynSpaceSearchDetailsReply\x12p\n\x10OfficialAccounts\x12,.bilibili.app.dynamic.v2.OfficialAccountsReq\x1a..bilibili.app.dynamic.v2.OfficialAccountsReply\x12p\n\x10OfficialDynamics\x12,.bilibili.app.dynamic.v2.OfficialDynamicsReq\x1a..bilibili.app.dynamic.v2.OfficialDynamicsReply\x12\x64\n\x0c\x43\x61mpusRedDot\x12(.bilibili.app.dynamic.v2.CampusRedDotReq\x1a*.bilibili.app.dynamic.v2.CampusRedDotReply\x12j\n\x0e\x43\x61mpusRcmdFeed\x12*.bilibili.app.dynamic.v2.CampusRcmdFeedReq\x1a,.bilibili.app.dynamic.v2.CampusRcmdFeedReply\x12\x61\n\x0bTopicSquare\x12\'.bilibili.app.dynamic.v2.TopicSquareReq\x1a).bilibili.app.dynamic.v2.TopicSquareReply\x12[\n\tTopicList\x12%.bilibili.app.dynamic.v2.TopicListReq\x1a\'.bilibili.app.dynamic.v2.TopicListReply\x12v\n\x12\x43\x61mpusMateLikeList\x12..bilibili.app.dynamic.v2.CampusMateLikeListReq\x1a\x30.bilibili.app.dynamic.v2.CampusMateLikeListReply\x12j\n\x0e\x43\x61mpusFeedback\x12*.bilibili.app.dynamic.v2.CampusFeedbackReq\x1a,.bilibili.app.dynamic.v2.CampusFeedbackReply\x12m\n\x0f\x43\x61mpusBillboard\x12+.bilibili.app.dynamic.v2.CampusBillBoardReq\x1a-.bilibili.app.dynamic.v2.CampusBillBoardReply\x12}\n\x17\x43\x61mpusBillboardInternal\x12\x33.bilibili.app.dynamic.v2.CampusBillboardInternalReq\x1a-.bilibili.app.dynamic.v2.CampusBillBoardReply\x12y\n\x13\x43\x61mpusTopicRcmdFeed\x12/.bilibili.app.dynamic.v2.CampusTopicRcmdFeedReq\x1a\x31.bilibili.app.dynamic.v2.CampusTopicRcmdFeedReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.dynamic.v2.dynamic_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DYNSERVERDETAILSREPLY_ITEMSENTRY._options = None
  _DYNSERVERDETAILSREPLY_ITEMSENTRY._serialized_options = b'8\001'
  _DYNSPACESEARCHDETAILSREPLY_ITEMSENTRY._options = None
  _DYNSPACESEARCHDETAILSREPLY_ITEMSENTRY._serialized_options = b'8\001'
  _ADDBUTTONBGSTYLE._serialized_start=44623
  _ADDBUTTONBGSTYLE._serialized_end=44673
  _ADDBUTTONTYPE._serialized_start=44675
  _ADDBUTTONTYPE._serialized_end=44731
  _ADDITIONVOTESTATE._serialized_start=44733
  _ADDITIONVOTESTATE._serialized_end=44843
  _ADDITIONVOTETYPE._serialized_start=44846
  _ADDITIONVOTETYPE._serialized_end=44982
  _ADDITIONALBUTTONCLICKTYPE._serialized_start=44984
  _ADDITIONALBUTTONCLICKTYPE._serialized_end=45041
  _ADDITIONALBUTTONSTATUS._serialized_start=45043
  _ADDITIONALBUTTONSTATUS._serialized_end=45101
  _ADDITIONALSHARESHOWTYPE._serialized_start=45103
  _ADDITIONALSHARESHOWTYPE._serialized_end=45154
  _ADDITIONALTYPE._serialized_start=45157
  _ADDITIONALTYPE._serialized_end=45418
  _CAMPUSTABTYPE._serialized_start=45421
  _CAMPUSTABTYPE._serialized_end=45552
  _COVERICON._serialized_start=45554
  _COVERICON._serialized_end=45607
  _DESCTYPE._serialized_start=45610
  _DESCTYPE._serialized_end=46014
  _DISABLESTATE._serialized_start=46016
  _DISABLESTATE._serialized_end=46055
  _DYNEXTENDTYPE._serialized_start=46058
  _DYNEXTENDTYPE._serialized_end=46287
  _DYNMODULETYPE._serialized_start=46290
  _DYNMODULETYPE._serialized_end=46875
  _DYNURITYPE._serialized_start=46877
  _DYNURITYPE._serialized_end=46962
  _DYNAMICTYPE._serialized_start=46965
  _DYNAMICTYPE._serialized_end=47304
  _EMOJITYPE._serialized_start=47306
  _EMOJITYPE._serialized_end=47372
  _ESPACESTYLE._serialized_start=47374
  _ESPACESTYLE._serialized_end=47397
  _FOLDTYPE._serialized_start=47399
  _FOLDTYPE._serialized_end=47508
  _FOLLOWTYPE._serialized_start=47510
  _FOLLOWTYPE._serialized_end=47556
  _HIGHLIGHTTEXTSTYLE._serialized_start=47558
  _HIGHLIGHTTEXTSTYLE._serialized_end=47615
  _IMAGESTYLE._serialized_start=47617
  _IMAGESTYLE._serialized_end=47675
  _LIGHTFROMTYPE._serialized_start=47677
  _LIGHTFROMTYPE._serialized_end=47726
  _LIVESTATE._serialized_start=47728
  _LIVESTATE._serialized_end=47788
  _LOCALICONTYPE._serialized_start=47790
  _LOCALICONTYPE._serialized_end=47850
  _MDLDYNCOMMONTYPE._serialized_start=47852
  _MDLDYNCOMMONTYPE._serialized_end=47950
  _MDLDYNDRAWTAGTYPE._serialized_start=47953
  _MDLDYNDRAWTAGTYPE._serialized_end=48113
  _MDLDYNSUBSCRIPTIONNEWSTYLE._serialized_start=48116
  _MDLDYNSUBSCRIPTIONNEWSTYLE._serialized_end=48267
  _MEDIATYPE._serialized_start=48269
  _MEDIATYPE._serialized_end=48372
  _MODULEAUTHORBADGETYPE._serialized_start=48375
  _MODULEAUTHORBADGETYPE._serialized_end=48548
  _MODULEBANNERTYPE._serialized_start=48550
  _MODULEBANNERTYPE._serialized_end=48626
  _MODULEDYNAMICTYPE._serialized_start=48629
  _MODULEDYNAMICTYPE._serialized_end=48998
  _NETWORKTYPE._serialized_start=49000
  _NETWORKTYPE._serialized_end=49094
  _RCMDTYPE._serialized_start=49096
  _RCMDTYPE._serialized_end=49142
  _REFRESH._serialized_start=49144
  _REFRESH._serialized_end=49191
  _RELATIONSTATUS._serialized_start=49194
  _RELATIONSTATUS._serialized_end=49389
  _REPOSTTYPE._serialized_start=49391
  _REPOSTTYPE._serialized_end=49439
  _RESERVERELATIONLOTTERYTYPE._serialized_start=49441
  _RESERVERELATIONLOTTERYTYPE._serialized_end=49552
  _RESERVETYPE._serialized_start=49554
  _RESERVETYPE._serialized_end=49605
  _SHOWTYPE._serialized_start=49607
  _SHOWTYPE._serialized_end=49659
  _STYLETYPE._serialized_start=49661
  _STYLETYPE._serialized_end=49737
  _TFTYPE._serialized_start=49739
  _TFTYPE._serialized_end=49816
  _THREEPOINTATTENTIONSTATUS._serialized_start=49818
  _THREEPOINTATTENTIONSTATUS._serialized_end=49885
  _THREEPOINTTYPE._serialized_start=49888
  _THREEPOINTTYPE._serialized_end=50108
  _THUMBTYPE._serialized_start=50110
  _THUMBTYPE._serialized_end=50144
  _TOPTYPE._serialized_start=50146
  _TOPTYPE._serialized_end=50185
  _USERITEMTYPE._serialized_start=50188
  _USERITEMTYPE._serialized_end=50338
  _VIDEOSUBTYPE._serialized_start=50341
  _VIDEOSUBTYPE._serialized_end=50506
  _VIDEOTYPE._serialized_start=50508
  _VIDEOTYPE._serialized_end=50614
  _VOTESTATUS._serialized_start=50616
  _VOTESTATUS._serialized_end=50655
  _WEIGHTTYPE._serialized_start=50657
  _WEIGHTTYPE._serialized_end=50723
  _ADPARAM._serialized_start=143
  _ADPARAM._serialized_end=190
  _ADDITIONCOMMON._serialized_start=193
  _ADDITIONCOMMON._serialized_end=480
  _ADDITIONESPORT._serialized_start=483
  _ADDITIONESPORT._serialized_end=670
  _ADDITIONESPORTMOBA._serialized_start=673
  _ADDITIONESPORTMOBA._serialized_end=1014
  _ADDITIONESPORTMOBASTATUS._serialized_start=1017
  _ADDITIONESPORTMOBASTATUS._serialized_end=1207
  _ADDITIONESPORTMOBASTATUSDESC._serialized_start=1209
  _ADDITIONESPORTMOBASTATUSDESC._serialized_end=1290
  _ADDITIONGOODS._serialized_start=1293
  _ADDITIONGOODS._serialized_end=1451
  _ADDITIONUP._serialized_start=1454
  _ADDITIONUP._serialized_end=1991
  _ADDITIONUGC._serialized_start=1994
  _ADDITIONUGC._serialized_end=2167
  _ADDITIONUSERINFO._serialized_start=2169
  _ADDITIONUSERINFO._serialized_end=2215
  _ADDITIONVOTE._serialized_start=2217
  _ADDITIONVOTE._serialized_end=2315
  _ADDITIONVOTE2._serialized_start=2318
  _ADDITIONVOTE2._serialized_end=2965
  _ADDITIONVOTEDEFAULE._serialized_start=2967
  _ADDITIONVOTEDEFAULE._serialized_end=3003
  _ADDITIONVOTEPIC._serialized_start=3005
  _ADDITIONVOTEPIC._serialized_end=3082
  _ADDITIONVOTEPICITEM._serialized_start=3085
  _ADDITIONVOTEPICITEM._serialized_end=3225
  _ADDITIONVOTEWORD._serialized_start=3227
  _ADDITIONVOTEWORD._serialized_end=3306
  _ADDITIONVOTEWORDITEM._serialized_start=3308
  _ADDITIONVOTEWORDITEM._serialized_end=3434
  _ADDITIONALACTSKIN._serialized_start=3436
  _ADDITIONALACTSKIN._serialized_end=3509
  _ADDITIONALBUTTON._serialized_start=3512
  _ADDITIONALBUTTON._serialized_end=3935
  _ADDITIONALBUTTONINTERACTIVE._serialized_start=3937
  _ADDITIONALBUTTONINTERACTIVE._serialized_end=4029
  _ADDITIONALBUTTONSHARE._serialized_start=4031
  _ADDITIONALBUTTONSHARE._serialized_end=4096
  _ADDITIONALBUTTONSTYLE._serialized_start=4099
  _ADDITIONALBUTTONSTYLE._serialized_end=4420
  _ADDITIONALPGC._serialized_start=4423
  _ADDITIONALPGC._serialized_end=4690
  _ALUMNIDYNAMICSREPLY._serialized_start=4692
  _ALUMNIDYNAMICSREPLY._serialized_end=4780
  _ALUMNIDYNAMICSREQ._serialized_start=4783
  _ALUMNIDYNAMICSREQ._serialized_end=4944
  _CAMPUSBANNERINFO._serialized_start=4946
  _CAMPUSBANNERINFO._serialized_end=4997
  _CAMPUSBILLBOARDREPLY._serialized_start=5000
  _CAMPUSBILLBOARDREPLY._serialized_end=5252
  _CAMPUSBILLBOARDREQ._serialized_start=5255
  _CAMPUSBILLBOARDREQ._serialized_end=5385
  _CAMPUSBILLBOARDINTERNALREQ._serialized_start=5387
  _CAMPUSBILLBOARDINTERNALREQ._serialized_end=5469
  _CAMPUSFEEDBACKINFO._serialized_start=5471
  _CAMPUSFEEDBACKINFO._serialized_end=5560
  _CAMPUSFEEDBACKREPLY._serialized_start=5562
  _CAMPUSFEEDBACKREPLY._serialized_end=5600
  _CAMPUSFEEDBACKREQ._serialized_start=5602
  _CAMPUSFEEDBACKREQ._serialized_end=5695
  _CAMPUSINFO._serialized_start=5697
  _CAMPUSINFO._serialized_end=5779
  _CAMPUSLABEL._serialized_start=5781
  _CAMPUSLABEL._serialized_end=5835
  _CAMPUSMATELIKELISTREPLY._serialized_start=5837
  _CAMPUSMATELIKELISTREPLY._serialized_end=5915
  _CAMPUSMATELIKELISTREQ._serialized_start=5917
  _CAMPUSMATELIKELISTREQ._serialized_end=5960
  _CAMPUSNOTICEINFO._serialized_start=5962
  _CAMPUSNOTICEINFO._serialized_end=6063
  _CAMPUSRCMDFEEDREPLY._serialized_start=6066
  _CAMPUSRCMDFEEDREPLY._serialized_end=6246
  _CAMPUSRCMDFEEDREQ._serialized_start=6249
  _CAMPUSRCMDFEEDREQ._serialized_end=6447
  _CAMPUSRCMDINFO._serialized_start=6449
  _CAMPUSRCMDINFO._serialized_end=6536
  _CAMPUSRCMDITEM._serialized_start=6539
  _CAMPUSRCMDITEM._serialized_end=6698
  _CAMPUSRCMDREPLY._serialized_start=6701
  _CAMPUSRCMDREPLY._serialized_end=6901
  _CAMPUSRCMDREQ._serialized_start=6904
  _CAMPUSRCMDREQ._serialized_end=7054
  _CAMPUSRCMDTOP._serialized_start=7057
  _CAMPUSRCMDTOP._serialized_end=7506
  _CAMPUSREDDOTREPLY._serialized_start=7508
  _CAMPUSREDDOTREPLY._serialized_end=7544
  _CAMPUSREDDOTREQ._serialized_start=7546
  _CAMPUSREDDOTREQ._serialized_end=7582
  _CAMPUSSHOWTABINFO._serialized_start=7584
  _CAMPUSSHOWTABINFO._serialized_end=7661
  _CAMPUSTOP._serialized_start=7664
  _CAMPUSTOP._serialized_end=8139
  _CAMPUSTOPICRCMDFEEDREPLY._serialized_start=8141
  _CAMPUSTOPICRCMDFEEDREPLY._serialized_end=8268
  _CAMPUSTOPICRCMDFEEDREQ._serialized_start=8271
  _CAMPUSTOPICRCMDFEEDREQ._serialized_end=8419
  _CARDVIDEODYNLIST._serialized_start=8422
  _CARDVIDEODYNLIST._serialized_end=8579
  _CARDVIDEOFOLLOWLIST._serialized_start=8581
  _CARDVIDEOFOLLOWLIST._serialized_end=8680
  _CARDVIDEOUPLIST._serialized_start=8683
  _CARDVIDEOUPLIST._serialized_end=8969
  _CHANNELINFO._serialized_start=8972
  _CHANNELINFO._serialized_end=9160
  _CMTSHOWITEM._serialized_start=9162
  _CMTSHOWITEM._serialized_end=9233
  _COMMENTDETAIL._serialized_start=9235
  _COMMENTDETAIL._serialized_end=9286
  _DECOCARDFAN._serialized_start=9288
  _DECOCARDFAN._serialized_end=9368
  _DECORATECARD._serialized_start=9370
  _DECORATECARD._serialized_end=9483
  _DESCRIPTION._serialized_start=9486
  _DESCRIPTION._serialized_end=9797
  _DIMENSION._serialized_start=9799
  _DIMENSION._serialized_end=9857
  _DYNADDITIONCOMMONFOLLOWREPLY._serialized_start=9859
  _DYNADDITIONCOMMONFOLLOWREPLY._serialized_end=9954
  _DYNADDITIONCOMMONFOLLOWREQ._serialized_start=9957
  _DYNADDITIONCOMMONFOLLOWREQ._serialized_end=10085
  _DYNALLPERSONALREPLY._serialized_start=10088
  _DYNALLPERSONALREPLY._serialized_end=10330
  _DYNALLPERSONALREQ._serialized_start=10333
  _DYNALLPERSONALREQ._serialized_end=10604
  _DYNALLREPLY._serialized_start=10607
  _DYNALLREPLY._serialized_end=10909
  _DYNALLREQ._serialized_start=10912
  _DYNALLREQ._serialized_end=11408
  _DYNALLUPDOFFSETREQ._serialized_start=11410
  _DYNALLUPDOFFSETREQ._serialized_end=11488
  _DYNDETAILREPLY._serialized_start=11490
  _DYNDETAILREPLY._serialized_end=11558
  _DYNDETAILREQ._serialized_start=11561
  _DYNDETAILREQ._serialized_end=11849
  _DYNDETAILSREPLY._serialized_start=11851
  _DYNDETAILSREPLY._serialized_end=11920
  _DYNDETAILSREQ._serialized_start=11923
  _DYNDETAILSREQ._serialized_end=12110
  _DYNFAKECARDREPLY._serialized_start=12112
  _DYNFAKECARDREPLY._serialized_end=12182
  _DYNFAKECARDREQ._serialized_start=12184
  _DYNFAKECARDREQ._serialized_end=12217
  _DYNLIGHTREPLY._serialized_start=12219
  _DYNLIGHTREPLY._serialized_end=12294
  _DYNLIGHTREQ._serialized_start=12297
  _DYNLIGHTREQ._serialized_end=12488
  _DYNMIXUPLISTVIEWMOREREPLY._serialized_start=12491
  _DYNMIXUPLISTVIEWMOREREPLY._serialized_end=12714
  _DYNMIXUPLISTVIEWMOREREQ._serialized_start=12716
  _DYNMIXUPLISTVIEWMOREREQ._serialized_end=12760
  _DYNRCMDREPLY._serialized_start=12763
  _DYNRCMDREPLY._serialized_end=12898
  _DYNRCMDREQ._serialized_start=12901
  _DYNRCMDREQ._serialized_end=13040
  _DYNRCMDUPEXCHANGEREPLY._serialized_start=13042
  _DYNRCMDUPEXCHANGEREPLY._serialized_end=13119
  _DYNRCMDUPEXCHANGEREQ._serialized_start=13121
  _DYNRCMDUPEXCHANGEREQ._serialized_end=13189
  _DYNREGIONRCMD._serialized_start=13191
  _DYNREGIONRCMD._serialized_end=13316
  _DYNREGIONRCMDITEM._serialized_start=13318
  _DYNREGIONRCMDITEM._serialized_end=13417
  _DYNSEARCHREPLY._serialized_start=13420
  _DYNSEARCHREPLY._serialized_end=13616
  _DYNSEARCHREQ._serialized_start=13619
  _DYNSEARCHREQ._serialized_end=13753
  _DYNSERVERDETAILSREPLY._serialized_start=13756
  _DYNSERVERDETAILSREPLY._serialized_end=13937
  _DYNSERVERDETAILSREPLY_ITEMSENTRY._serialized_start=13855
  _DYNSERVERDETAILSREPLY_ITEMSENTRY._serialized_end=13937
  _DYNSERVERDETAILSREQ._serialized_start=13940
  _DYNSERVERDETAILSREQ._serialized_end=14164
  _DYNSPACEREQ._serialized_start=14167
  _DYNSPACEREQ._serialized_end=14339
  _DYNSPACERSP._serialized_start=14341
  _DYNSPACERSP._serialized_end=14448
  _DYNSPACESEARCHDETAILSREPLY._serialized_start=14451
  _DYNSPACESEARCHDETAILSREPLY._serialized_end=14642
  _DYNSPACESEARCHDETAILSREPLY_ITEMSENTRY._serialized_start=13855
  _DYNSPACESEARCHDETAILSREPLY_ITEMSENTRY._serialized_end=13937
  _DYNSPACESEARCHDETAILSREQ._serialized_start=14645
  _DYNSPACESEARCHDETAILSREQ._serialized_end=14924
  _DYNTAB._serialized_start=14927
  _DYNTAB._serialized_end=15223
  _DYNTABREPLY._serialized_start=15225
  _DYNTABREPLY._serialized_end=15288
  _DYNTABREQ._serialized_start=15290
  _DYNTABREQ._serialized_end=15325
  _DYNTHUMBREQ._serialized_start=15327
  _DYNTHUMBREQ._serialized_end=15450
  _DYNVIDEOPERSONALREPLY._serialized_start=15453
  _DYNVIDEOPERSONALREPLY._serialized_end=15697
  _DYNVIDEOPERSONALREQ._serialized_start=15700
  _DYNVIDEOPERSONALREQ._serialized_end=15973
  _DYNVIDEOREPLY._serialized_start=15976
  _DYNVIDEOREPLY._serialized_end=16194
  _DYNVIDEOREQ._serialized_start=16197
  _DYNVIDEOREQ._serialized_end=16511
  _DYNVIDEOUPDOFFSETREQ._serialized_start=16513
  _DYNVIDEOUPDOFFSETREQ._serialized_end=16593
  _DYNVOTEREPLY._serialized_start=16595
  _DYNVOTEREPLY._serialized_end=16678
  _DYNVOTEREQ._serialized_start=16681
  _DYNVOTEREQ._serialized_end=16813
  _DYNAMICITEM._serialized_start=16816
  _DYNAMICITEM._serialized_end=17081
  _DYNAMICLIST._serialized_start=17084
  _DYNAMICLIST._serialized_end=17236
  _EXTINFOCOMMON._serialized_start=17239
  _EXTINFOCOMMON._serialized_end=17465
  _EXTINFOGAME._serialized_start=17467
  _EXTINFOGAME._serialized_end=17522
  _EXTINFOHOT._serialized_start=17524
  _EXTINFOHOT._serialized_end=17578
  _EXTINFOLBS._serialized_start=17580
  _EXTINFOLBS._serialized_end=17652
  _EXTINFOOGV._serialized_start=17654
  _EXTINFOOGV._serialized_end=17718
  _EXTINFOTOPIC._serialized_start=17720
  _EXTINFOTOPIC._serialized_end=17776
  _EXTEND._serialized_start=17779
  _EXTEND._serialized_end=18311
  _EXTENDREPLY._serialized_start=18313
  _EXTENDREPLY._serialized_end=18398
  _EXTENDREPLYPARAM._serialized_start=18400
  _EXTENDREPLYPARAM._serialized_end=18446
  _FOLLOWLISTITEM._serialized_start=18449
  _FOLLOWLISTITEM._serialized_end=18607
  _GOODSITEM._serialized_start=18610
  _GOODSITEM._serialized_end=18868
  _GUIDEBARINFO._serialized_start=18870
  _GUIDEBARINFO._serialized_end=18986
  _HIGHLIGHTTEXT._serialized_start=18988
  _HIGHLIGHTTEXT._serialized_end=19114
  _ICONBADGE._serialized_start=19116
  _ICONBADGE._serialized_end=19162
  _ICONBUTTON._serialized_start=19164
  _ICONBUTTON._serialized_end=19246
  _INFOOGV._serialized_start=19248
  _INFOOGV._serialized_end=19319
  _INTERACTIONFACE._serialized_start=19321
  _INTERACTIONFACE._serialized_end=19365
  _INTERACTIONITEM._serialized_start=19368
  _INTERACTIONITEM._serialized_end=19677
  _INTERACTIONSTAT._serialized_start=19679
  _INTERACTIONSTAT._serialized_end=19710
  _LIKEANIMATION._serialized_start=19712
  _LIKEANIMATION._serialized_end=19791
  _LIKEINFO._serialized_start=19793
  _LIKEINFO._serialized_end=19879
  _LIKELISTREPLY._serialized_start=19881
  _LIKELISTREPLY._serialized_end=19988
  _LIKELISTREQ._serialized_start=19990
  _LIKELISTREQ._serialized_end=20088
  _LIKEUSER._serialized_start=20090
  _LIKEUSER._serialized_end=20141
  _LIVEINFO._serialized_start=20143
  _LIVEINFO._serialized_end=20241
  _LIVEPENDANT._serialized_start=20243
  _LIVEPENDANT._serialized_end=20304
  _MATCHTEAM._serialized_start=20306
  _MATCHTEAM._serialized_end=20394
  _MDLDYNAPPLET._serialized_start=20397
  _MDLDYNAPPLET._serialized_end=20536
  _MDLDYNARCHIVE._serialized_start=20539
  _MDLDYNARCHIVE._serialized_end=21272
  _MDLDYNARTICLE._serialized_start=21274
  _MDLDYNARTICLE._serialized_end=21394
  _MDLDYNCOMMON._serialized_start=21397
  _MDLDYNCOMMON._serialized_end=21700
  _MDLDYNCOURBATCH._serialized_start=21703
  _MDLDYNCOURBATCH._serialized_end=21866
  _MDLDYNCOURSEASON._serialized_start=21869
  _MDLDYNCOURSEASON._serialized_end=22031
  _MDLDYNDRAW._serialized_start=22033
  _MDLDYNDRAW._serialized_end=22126
  _MDLDYNDRAWITEM._serialized_start=22129
  _MDLDYNDRAWITEM._serialized_end=22257
  _MDLDYNDRAWTAG._serialized_start=22260
  _MDLDYNDRAWTAG._serialized_end=22391
  _MDLDYNDRAWTAGITEM._serialized_start=22394
  _MDLDYNDRAWTAGITEM._serialized_end=22575
  _MDLDYNFORWARD._serialized_start=22577
  _MDLDYNFORWARD._serialized_end=22659
  _MDLDYNLIVE._serialized_start=22662
  _MDLDYNLIVE._serialized_end=22940
  _MDLDYNLIVERCMD._serialized_start=22943
  _MDLDYNLIVERCMD._serialized_end=23091
  _MDLDYNMEDIALIST._serialized_start=23094
  _MDLDYNMEDIALIST._serialized_end=23257
  _MDLDYNMUSIC._serialized_start=23259
  _MDLDYNMUSIC._serialized_end=23373
  _MDLDYNPGC._serialized_start=23376
  _MDLDYNPGC._serialized_end=24016
  _MDLDYNSUBSCRIPTION._serialized_start=24019
  _MDLDYNSUBSCRIPTION._serialized_end=24193
  _MDLDYNSUBSCRIPTIONNEW._serialized_start=24196
  _MDLDYNSUBSCRIPTIONNEW._serialized_end=24434
  _MDLDYNUGCSEASON._serialized_start=24437
  _MDLDYNUGCSEASON._serialized_end=24764
  _MIXUPLISTITEM._serialized_start=24767
  _MIXUPLISTITEM._serialized_end=25130
  _MIXUPLISTLIVEITEM._serialized_start=25132
  _MIXUPLISTLIVEITEM._serialized_end=25197
  _MODULE._serialized_start=25200
  _MODULE._serialized_end=27011
  _MODULEAD._serialized_start=27014
  _MODULEAD._serialized_end=27235
  _MODULEADDITIONAL._serialized_start=27238
  _MODULEADDITIONAL._serialized_end=27807
  _MODULEAUTHOR._serialized_start=27810
  _MODULEAUTHOR._serialized_end=28391
  _MODULEAUTHORBADGEBUTTON._serialized_start=28393
  _MODULEAUTHORBADGEBUTTON._serialized_end=28474
  _MODULEAUTHORFORWARD._serialized_start=28477
  _MODULEAUTHORFORWARD._serialized_end=28766
  _MODULEAUTHORFORWARDTITLE._serialized_start=28768
  _MODULEAUTHORFORWARDTITLE._serialized_end=28821
  _MODULEBANNER._serialized_start=28824
  _MODULEBANNER._serialized_end=29021
  _MODULEBANNERUSER._serialized_start=29023
  _MODULEBANNERUSER._serialized_end=29102
  _MODULEBANNERUSERITEM._serialized_start=29105
  _MODULEBANNERUSERITEM._serialized_end=29417
  _MODULEBUTTOM._serialized_start=29419
  _MODULEBUTTOM._serialized_end=29491
  _MODULECOMMENT._serialized_start=29493
  _MODULECOMMENT._serialized_end=29567
  _MODULEDESC._serialized_start=29569
  _MODULEDESC._serialized_end=29665
  _MODULEDESCGOODS._serialized_start=29668
  _MODULEDESCGOODS._serialized_end=29853
  _MODULEDISPUTE._serialized_start=29855
  _MODULEDISPUTE._serialized_end=29912
  _MODULEDYNAMIC._serialized_start=29915
  _MODULEDYNAMIC._serialized_end=31041
  _MODULEEXTEND._serialized_start=31043
  _MODULEEXTEND._serialized_end=31129
  _MODULEEXTENDITEM._serialized_start=31132
  _MODULEEXTENDITEM._serialized_end=31592
  _MODULEFOLD._serialized_start=31595
  _MODULEFOLD._serialized_end=31748
  _MODULEINTERACTION._serialized_start=31750
  _MODULEINTERACTION._serialized_end=31837
  _MODULEITEMNULL._serialized_start=31839
  _MODULEITEMNULL._serialized_end=31883
  _MODULELIKEUSER._serialized_start=31885
  _MODULELIKEUSER._serialized_end=31978
  _MODULERCMD._serialized_start=31981
  _MODULERCMD._serialized_end=32117
  _MODULERECOMMEND._serialized_start=32120
  _MODULERECOMMEND._serialized_end=32254
  _MODULESHAREINFO._serialized_start=32257
  _MODULESHAREINFO._serialized_end=32400
  _MODULESTAT._serialized_start=32403
  _MODULESTAT._serialized_end=32623
  _MODULESTORY._serialized_start=32626
  _MODULESTORY._serialized_end=32806
  _MODULETITLE._serialized_start=32808
  _MODULETITLE._serialized_end=32892
  _MODULETOP._serialized_start=32894
  _MODULETOP._serialized_end=32963
  _MODULETOPTAG._serialized_start=32965
  _MODULETOPTAG._serialized_end=32997
  _MODULETOPIC._serialized_start=32999
  _MODULETOPIC._serialized_end=33051
  _MODULETOPICBRIEF._serialized_start=33053
  _MODULETOPICBRIEF._serialized_end=33122
  _MODULETOPICDETAILSEXT._serialized_start=33124
  _MODULETOPICDETAILSEXT._serialized_end=33170
  _NAMEPLATE._serialized_start=33172
  _NAMEPLATE._serialized_end=33280
  _NEWEP._serialized_start=33282
  _NEWEP._serialized_end=33336
  _NOREPLY._serialized_start=33338
  _NOREPLY._serialized_end=33347
  _NOREQ._serialized_start=33349
  _NOREQ._serialized_end=33356
  _OFFICIALACCOUNTINFO._serialized_start=33359
  _OFFICIALACCOUNTINFO._serialized_end=33550
  _OFFICIALACCOUNTSREPLY._serialized_start=33552
  _OFFICIALACCOUNTSREPLY._serialized_end=33670
  _OFFICIALACCOUNTSREQ._serialized_start=33672
  _OFFICIALACCOUNTSREQ._serialized_end=33749
  _OFFICIALDYNAMICSREPLY._serialized_start=33752
  _OFFICIALDYNAMICSREPLY._serialized_end=33932
  _OFFICIALDYNAMICSREQ._serialized_start=33934
  _OFFICIALDYNAMICSREQ._serialized_end=34011
  _OFFICIALITEM._serialized_start=34014
  _OFFICIALITEM._serialized_end=34195
  _OFFICIALRCMDARCHIVE._serialized_start=34198
  _OFFICIALRCMDARCHIVE._serialized_end=34483
  _OFFICIALRCMDDYNAMIC._serialized_start=34486
  _OFFICIALRCMDDYNAMIC._serialized_end=34741
  _OFFICIALVERIFY._serialized_start=34743
  _OFFICIALVERIFY._serialized_end=34805
  _PGCSEASON._serialized_start=34807
  _PGCSEASON._serialized_end=34866
  _PLAYURLPARAM._serialized_start=34868
  _PLAYURLPARAM._serialized_end=34959
  _POPUP._serialized_start=34961
  _POPUP._serialized_end=35010
  _RCMDARCHIVE._serialized_start=35013
  _RCMDARCHIVE._serialized_end=35343
  _RCMDAUTHOR._serialized_start=35346
  _RCMDAUTHOR._serialized_end=35476
  _RCMDITEM._serialized_start=35479
  _RCMDITEM._serialized_end=35613
  _RCMDOPTION._serialized_start=35615
  _RCMDOPTION._serialized_end=35647
  _RCMDTOPBUTTON._serialized_start=35649
  _RCMDTOPBUTTON._serialized_end=35691
  _RCMDUPSPARAM._serialized_start=35693
  _RCMDUPSPARAM._serialized_end=35727
  _RELATION._serialized_start=35729
  _RELATION._serialized_end=35851
  _REPOSTLISTREQ._serialized_start=35854
  _REPOSTLISTREQ._serialized_end=36008
  _REPOSTLISTRSP._serialized_start=36011
  _REPOSTLISTRSP._serialized_end=36191
  _REACTIONLISTREQ._serialized_start=36193
  _REACTIONLISTREQ._serialized_end=36277
  _REACTIONLISTREPLY._serialized_start=36279
  _REACTIONLISTREPLY._serialized_end=36404
  _REACTIONLISTITEM._serialized_start=36407
  _REACTIONLISTITEM._serialized_end=36566
  _SCHOOLRECOMMENDREPLY._serialized_start=36568
  _SCHOOLRECOMMENDREPLY._serialized_end=36642
  _SCHOOLRECOMMENDREQ._serialized_start=36644
  _SCHOOLRECOMMENDREQ._serialized_end=36690
  _SCHOOLSEARCHREPLY._serialized_start=36692
  _SCHOOLSEARCHREPLY._serialized_end=36816
  _SCHOOLSEARCHREQ._serialized_start=36818
  _SCHOOLSEARCHREQ._serialized_end=36852
  _SEARCHCHANNEL._serialized_start=36855
  _SEARCHCHANNEL._serialized_end=37006
  _SEARCHINFO._serialized_start=37009
  _SEARCHINFO._serialized_end=37156
  _SEARCHTOAST._serialized_start=37158
  _SEARCHTOAST._serialized_end=37211
  _SEARCHTOPIC._serialized_start=37214
  _SEARCHTOPIC._serialized_end=37364
  _SEARCHTOPICBUTTON._serialized_start=37366
  _SEARCHTOPICBUTTON._serialized_end=37418
  _SEARCHTOPICITEM._serialized_start=37420
  _SEARCHTOPICITEM._serialized_end=37523
  _SETDECISIONREQ._serialized_start=37525
  _SETDECISIONREQ._serialized_end=37557
  _SETRECENTCAMPUSREQ._serialized_start=37559
  _SETRECENTCAMPUSREQ._serialized_end=37619
  _SHARECHANNEL._serialized_start=37621
  _SHARECHANNEL._serialized_end=37737
  _SHARERESERVE._serialized_start=37740
  _SHARERESERVE._serialized_end=37910
  _SORTTYPE._serialized_start=37912
  _SORTTYPE._serialized_end=37965
  _STORYARCHIVE._serialized_start=37967
  _STORYARCHIVE._serialized_end=38077
  _STORYITEM._serialized_start=38080
  _STORYITEM._serialized_end=38263
  _SUBSCRIBECAMPUSREQ._serialized_start=38265
  _SUBSCRIBECAMPUSREQ._serialized_end=38325
  _THREEPOINTATTENTION._serialized_start=38328
  _THREEPOINTATTENTION._serialized_end=38521
  _THREEPOINTAUTOPLAY._serialized_start=38524
  _THREEPOINTAUTOPLAY._serialized_end=38750
  _THREEPOINTCOMMENT._serialized_start=38753
  _THREEPOINTCOMMENT._serialized_end=38921
  _THREEPOINTDEFAULT._serialized_start=38924
  _THREEPOINTDEFAULT._serialized_end=39061
  _THREEPOINTDEFAULTTOAST._serialized_start=39063
  _THREEPOINTDEFAULTTOAST._serialized_end=39116
  _THREEPOINTDISLIKE._serialized_start=39118
  _THREEPOINTDISLIKE._serialized_end=39166
  _THREEPOINTFAVORITE._serialized_start=39168
  _THREEPOINTFAVORITE._serialized_end=39294
  _THREEPOINTHIDE._serialized_start=39297
  _THREEPOINTHIDE._serialized_end=39454
  _THREEPOINTHIDEINTERACTIVE._serialized_start=39456
  _THREEPOINTHIDEINTERACTIVE._serialized_end=39546
  _THREEPOINTITEM._serialized_start=39549
  _THREEPOINTITEM._serialized_end=40325
  _THREEPOINTSHARE._serialized_start=40328
  _THREEPOINTSHARE._serialized_end=40518
  _THREEPOINTSHARECHANNEL._serialized_start=40520
  _THREEPOINTSHARECHANNEL._serialized_end=40573
  _THREEPOINTTOP._serialized_start=40575
  _THREEPOINTTOP._serialized_end=40667
  _THREEPOINTTOPICIRRELEVANT._serialized_start=40670
  _THREEPOINTTOPICIRRELEVANT._serialized_end=40809
  _THREEPOINTWAIT._serialized_start=40811
  _THREEPOINTWAIT._serialized_end=40937
  _TOPADDITIONUP._serialized_start=40939
  _TOPADDITIONUP._serialized_end=41021
  _TOPICBUTTON._serialized_start=41023
  _TOPICBUTTON._serialized_end=41100
  _TOPICITEM._serialized_start=41102
  _TOPICITEM._serialized_end=41212
  _TOPICLIST._serialized_start=41215
  _TOPICLIST._serialized_end=41444
  _TOPICLISTITEM._serialized_start=41447
  _TOPICLISTITEM._serialized_end=41662
  _TOPICLISTREPLY._serialized_start=41664
  _TOPICLISTREPLY._serialized_end=41765
  _TOPICLISTREQ._serialized_start=41767
  _TOPICLISTREQ._serialized_end=41816
  _TOPICRCMDCARD._serialized_start=41819
  _TOPICRCMDCARD._serialized_end=41990
  _TOPICSQUAREINFO._serialized_start=41993
  _TOPICSQUAREINFO._serialized_end=42133
  _TOPICSQUAREREPLY._serialized_start=42135
  _TOPICSQUAREREPLY._serialized_end=42209
  _TOPICSQUAREREQ._serialized_start=42211
  _TOPICSQUAREREQ._serialized_end=42246
  _UNFOLLOW._serialized_start=42248
  _UNFOLLOW._serialized_end=42347
  _UNFOLLOWUSERITEM._serialized_start=42350
  _UNFOLLOWUSERITEM._serialized_end=42705
  _UPLISTITEM._serialized_start=42708
  _UPLISTITEM._serialized_end=43118
  _UPLISTMORELABEL._serialized_start=43120
  _UPLISTMORELABEL._serialized_end=43165
  _USERINFO._serialized_start=43168
  _USERINFO._serialized_end=43566
  _USERITEMSTYLE._serialized_start=43568
  _USERITEMSTYLE._serialized_end=43694
  _USERPENDANT._serialized_start=43696
  _USERPENDANT._serialized_end=43767
  _VIDEOBADGE._serialized_start=43770
  _VIDEOBADGE._serialized_end=43994
  _VIPINFO._serialized_start=43997
  _VIPINFO._serialized_end=44174
  _VIPLABEL._serialized_start=44176
  _VIPLABEL._serialized_end=44235
  _WEIGHT._serialized_start=44237
  _WEIGHT._serialized_end=44326
  _WEIGHTBUTTON._serialized_start=44328
  _WEIGHTBUTTON._serialized_end=44375
  _WEIGHTDISLIKE._serialized_start=44377
  _WEIGHTDISLIKE._serialized_end=44431
  _WEIGHTITEM._serialized_start=44434
  _WEIGHTITEM._serialized_end=44621
  _DYNAMIC._serialized_start=50726
  _DYNAMIC._serialized_end=55069
# @@protoc_insertion_point(module_scope)
